﻿---------------------------------------------------------------------------------------
-- NxOptions - Options
-- Copyright 2007-2012 Carbon Based Creations, LLC
---------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------
-- Carbonite - Addon for World of Warcraft(tm)
-- Copyright 2007-2012 Carbon Based Creations, LLC
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
---------------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Tables

local AceConfig 	= LibStub("AceConfig-3.0")
local AceConfigReg 	= LibStub("AceConfigRegistry-3.0")
local AceConfigDialog 	= LibStub("AceConfigDialog-3.0")

local modular_config = {}

local profiles

local function profilesConfig()
	if not profiles then
		profiles = {
			type = "group",
			name = "配置文件",
			args = {			
				line1 = {			
					type = "description",
					name = "你可以为每个角色指定不同的配置文件，使每个角色都有各自的自定义设置。",
					order = 1,
				},
				line2 = {
					type = "description",
					name = "重置当前配置文件为默认值。可以在你的配置文件损坏或者累觉不爱时使用。",
					order = 2,
				},
				bigbutton = {
					type = "execute",
					name = "重置配置文件",
					width = "normal",
					func = function () 
							for a,b in pairs (Nx.dbs) do
								b:ResetProfile(true,true)
							end	
					end,
					desc = "将当前配置文件重置为默认值。",
					order = 3,
				},
				current = {
					type = "description",
					name = "当前配置文件: |c00ffff00" .. Nx.db:GetCurrentProfile(),
					width = "double",
					order = 4,
				},
				line3 = {
					type = "description",
					name = "在文本框输入名称来新建一个配置文件，或者选择一个已经存在的配置文件。",
					order = 5,
				},
				newprof = {
					type = "input",
					name = "新建",
					desc = "新建一个配置文件",
					get = false,
					set = function (info, name)
						for a,b in pairs(Nx.dbs) do
							Nx.prt(name)
							b:SetProfile(name)
						end
					end,
					order = 6,
				},
				existing = {
					type = "select",
					style = "dropdown",
					name = "现存配置文件",
					values = Nx.db:GetProfiles(),
					get = function ()
						return Nx.db:GetCurrentProfile()
					end,
					set = function (info, name)
						for a,b in pairs (Nx.dbs) do
							b:SetProfile(name)
						end
					end,
					desc = "选择一个当前可用的配置文件",
					order = 7,
				},
				linebrk = {
					type = "description",
					name = "",
					width = "full",
					order = 8,
				},
				line4 = {
					type = "description",
					name = "从现存的配置文件中复制到当前设置。",
					order = 9,
				},
				copyfrom = {				
					type = "select",
					style = "dropdown",
					name = "现存配置文件",
					values = Nx.db:GetProfiles(),
					get = false,
					set = function (info, name)
						for a,b in pairs(Nx.dbs) do
							b:CopyProfile(name)
						end
					end,
					desc = "从现存的配置文件中复制到当前配置文件。",
					order = 10,			
				},
				linebrk2 = {
					type = "description",
					name = "",
					width = "full",
					order = 11,
				},
				line5 = {
					type = "description",
					name = "删除不再使用的配置文件以节省空间。",
					order = 12,
				},
				delete = {				
					type = "select",
					style = "dropdown",
					name = "删除配置文件",
					get = false,
					set = function (info, name)
						for a,b in pairs(Nx.dbs) do
							b:DeleteProfile(name)
						end
					end,					
					values = Nx.db:GetProfiles(),
					desc = "从数据库删除配置文件。",
					order = 13,			
				},				
			},
		}
	end
	return profiles
end
local config

local function mainConfig()
	if not config then	
		config = {
			type = "group",
			name = "Carbonite",
			args = {
				main = {
					order = 1,
					type = "group",
					name = "Main Options",
					args = {
						title = {
							type = "description",
							name = "\nCarbonite 是一个全功能的地图插件，可以让你使用谷歌地图方式操作游戏地图，并可以和暴雪自带游戏地图协同工作。\n\n通过不同的功能模块可以让你的游戏生活变得更加轻松惬意。" ..
							       "\n\n\n|cff9999ff版本: |cffd700ff" .. Nx.VERMAJOR .. "." .. (Nx.VERMINOR*10) .. "zhcn10\n" ..
								   "|cff9999ff维护: |cffd700ffRythal of Moon Guard\n" ..
								   "|cff9999ff网站: |cffd700ffhttp://www.wowinterface.com/downloads/info12965-Carbonite.html\n"..
								   "\n"..
								   "|cd700ffff如需获取支持，请访问WoW Interface的Carbonite论坛.\n"..
								   "|cd700ffff特别感谢: \n\n"..
								   "|cff9999ffCirax 制作 Carbonite2 Logo\n" ..
								   "|cff9999ffJimboBlue 对百科指南兴趣点位置的升级与确认\n\n"..	
								   "|r模块及部分设置项汉化：奈漠@艾莫莉丝\n任务与部分设置项汉化：和平哥@阿纳克洛斯\n\n|cd700ffff搜索Lair of the Cursed，去网站获取更多支持！",
						},
					},
				},
			},
		}
		for k, v in pairs(modular_config) do
			config.args[k] = (type(v) == "function") and v() or v
		end
	end
  return config
end

local battlegrounds
local function BGConfig()
	if not battlegrounds then	
		battlegrounds = {
			type = "group",
			name = "战场",
			args = {
				bgstats = {
					type = "toggle",
					name = "显示战场状态",
					width = "full",
					desc = "开启或关闭战场中的杀敌/死亡信息与荣誉获得显示。",
					get = function()
						return Nx.db.profile.Battleground.ShowStats 
					end,
					set = function()
						Nx.db.profile.Battleground.ShowStats = not Nx.db.profile.Battleground.ShowStats
					end,
				},
			},	  
		}
	end
	return battlegrounds
end

local general
local function generalOptions()
	if not general then
		general = {
			type = "group",
			name = "一般设置",
			args = {
				loginMsg = {
					order = 1,
					type = "toggle",
					width = "full",
					name = "显示登录信息",
					desc = "启用时, 在聊天窗显示Carbonite登录信息。",
					get = function()
						return Nx.db.profile.General.LoginHideVer 
					end,
					set = function()
						Nx.db.profile.General.LoginHideVer = not Nx.db.profile.General.LoginHideVer
					end,				
				},
				loginWin = {
					order = 2,
					type = "toggle",
					width = "full",
					name = "显示登录图像",
					desc = "启用时, 显示Carbonite的启动图像。\n",
					get = function()
						return Nx.db.profile.General.TitleOff 
					end,
					set = function()
						Nx.db.profile.General.TitleOff = not Nx.db.profile.General.TitleOff
					end,				
				},			
				loginSnd = {
					order = 3,
					type = "toggle",
					width = "full",
					name = "播放登录音效",
					desc = "启用时，当Carbonite载入完成时将会播放音效。",
					get = function()
						return Nx.db.profile.General.TitleSoundOn
					end,
					set = function()
						Nx.db.profile.General.TitleSoundOn = not Nx.db.profile.General.TitleSoundOn
					end,				
				},		
				spacer1 = {
					order = 4,
					type = "description",
					name = "\n",
				},
				chatWindow = {
					order = 5,
					type	= "select",
					name	= "默认聊天频道",
					desc	= "选择Carbonite信息输出到哪一个频道。",
					get	= function()
						local vals = Nx.Opts:CalcChoices("Chat")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.General.ChatMsgFrm) then
						     return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("Chat")						
						Nx.db.profile.General.ChatMsgFrm = vals[name]
						Nx.Opts:NXCmdUIChange()
					end,
					values	= function()
					    return Nx.Opts:CalcChoices("Chat")
					end,
				},				
				spacer2 = {
					order = 6,
					type = "description",
					name = "\n",
				},
				maxCamera = {
					order = 7,
					type = "toggle",
					width = "full",
					name = "强制最远镜头距离\n",
					desc = "启用时，将镜头的允许最远距离变得更远。",
					get = function()
						return Nx.db.profile.General.CameraForceMaxDist
					end,
					set = function()
						Nx.db.profile.General.CameraForceMaxDist = not Nx.db.profile.General.CameraForceMaxDist
						Nx.Opts:NXCmdCamForceMaxDist()
					end,				
				},		
				hideGriff = {
					order = 8,
					type = "toggle",
					width = "full",
					name = "隐藏动作条的狮鹫图像",
					desc = "尝试隐藏动作条两端的狮鹫图像。",
					get = function()
						return Nx.db.profile.General.GryphonsHide
					end,
					set = function()
						Nx.db.profile.General.GryphonsHide = not Nx.db.profile.General.GryphonsHide
						Nx.Opts:NXCmdGryphonsUpdate()
					end,				
				},						
			},
		}
	end
	return general
end

local map
local function mapConfig ()
	if not map then
		map = {
			type = "group",
			name = "地图设置",
			childGroups	= "tab",
			args = {
				mainMap = {
					type = "group",
					name = "地图设置",
					order = 1,
					args = {
						maxMap = {
							order = 1,
							type = "toggle",
							width = "full",
							name = "使用Carbonite地图替代暴雪地图 (Alt+M打开暴雪地图)\n",
							desc = "启用时，按M键将打开Carbonite地图而不是暴雪自带地图。",
							get = function()
								return Nx.db.profile.Map.MaxOverride
							end,
							set = function()
								Nx.db.profile.Map.MaxOverride = not Nx.db.profile.Map.MaxOverride							
							end,				
						},			
						compatability = {
							order = 2,
							type = "toggle",
							width = "full",
							name = "启用兼容模式",
							desc = "启用时, Carbonite在战斗中将会检测窗体函数以防止与其他窗体插件冲突并产生界面错误。",
							get = function()
								return Nx.db.profile.Map.Compatability
							end,
							set = function()
								Nx.db.profile.Map.Compatability = not Nx.db.profile.Map.Compatability
							end,
						},
						centerMap = {
							order = 2,
							type = "toggle",
							width = "full",
							name = "最大化时居中\n",
							desc = "启用时，当你最大化Carbonite地图时将会显示以你为中心的区域。",
							get = function()
								return Nx.db.profile.Map.MaxCenter
							end,
							set = function()
								Nx.db.profile.Map.MaxCenter = not Nx.db.profile.Map.MaxCenter
							end,				
						},							  						
						mouseIgnore = {
							order = 3,
							type = "toggle",
							width = "full",
							name = "小地图窗口忽略鼠标点击(需要按住Alt点击)\n",
							desc = "启用时，小地图窗口将忽略所有的鼠标点击，除非你按住Alt键。",
							get = function()
								return Nx.db.profile.Map.MouseIgnore
							end,
							set = function()
								Nx.db.profile.Map.MouseIgnore = not Nx.db.profile.Map.MouseIgnore							
							end,				
						},							  						
						maxMouseIgnore = {
							order = 4,
							type = "toggle",
							width = "full",
							name = "大地图窗口忽略鼠标点击(需要按住Alt点击)\n",
							desc = "启用时，大地图窗口将忽略所有的鼠标点击，除非你按住Alt键。",
							get = function()
								return Nx.db.profile.Map.MaxMouseIgnore
							end,
							set = function()
								Nx.db.profile.Map.MaxMouseIgnore = not Nx.db.profile.Map.MaxMouseIgnore
							end,				
						},
						ownMap = {
							order = 5,
							type = "toggle",
							width = "full",
							name = "将世界地图信息移动到大地图窗口\n",
							desc = "启用时，Carbonite将会把原始世界地图中的标记绘制在Carbonite大地图中。",
							get = function()
								return Nx.db.profile.Map.WOwn
							end,
							set = function()
								Nx.db.profile.Map.WOwn = not Nx.db.profile.Map.WOwn
							end,				
						},				
						restoreMap = {
							order = 6,
							type = "toggle",
							width = "full",
							name = "关闭地图而不是最小化\n",
							desc = "启用时，按M将会关闭大地图而不是切换到小地图。",
							get = function()
								return Nx.db.profile.Map.MaxRestoreHide
							end,
							set = function()
								Nx.db.profile.Map.MaxRestoreHide = not Nx.db.profile.Map.MaxRestoreHide
							end,				
						},		
						spacer1 = {
							order = 7,
							type = "description",
							name = "\n",
						},
						showPals = {
							order = 8,
							type = "toggle",							
							name = "显示主城中好友/公会成员位置",
							width = "full",
							desc = "启用时，Carbonite将会尝试在主城地图上绘制附近的好友与公会成员位置。",
							get = function()
								return Nx.db.profile.Map.ShowPalsInCities
							end,
							set = function()
								Nx.db.profile.Map.ShowPalsInCities = not Nx.db.profile.Map.ShowPalsInCities
							end,				
						},
						showOthers = {
							order = 9,
							type = "toggle",							
							width = "full",
							name = "显示主城中其他Carbonite用户",
							desc = "启用时，将会在地图上显示其他同阵营Carbonite用户的位置。",
							get = function()
								return Nx.db.profile.Map.ShowOthersInCities
							end,
							set = function()
								Nx.db.profile.Map.ShowOthersInCities = not Nx.db.profile.Map.ShowOthersInCities
							end,				
						},
						showOthersZ = {
							order = 10,
							type = "toggle",			
							width = "full",
							name = "显示区域内其他Carbonite用户",
							desc = "启用时，将会在地图上显示其他同阵营Carbonite用户的位置。",
							get = function()
								return Nx.db.profile.Map.ShowOthersInZone
							end,
							set = function()
								Nx.db.profile.Map.ShowOthersInZone = not Nx.db.profile.Map.ShowOthersInZone
							end,				
						},
						spacer2 = {
							order = 11,
							type = "description",
							name = "\n",
						},				
						restoreScale = {
							order = 12,
							type = "toggle",							
							name = "追踪完成后恢复地图缩放",
							width = "full",
							desc = "启用时，追踪完成后将恢复地图为之前的缩放。",
							get = function()
								return Nx.db.profile.Map.RestoreScaleAfterTrack
							end,
							set = function()
								Nx.db.profile.Map.RestoreScaleAfterTrack = not Nx.db.profile.Map.RestoreScaleAfterTrack
							end,				
						},
						useRoute = {
							order = 13,
							type = "toggle",							
							name = "使用旅行路径规划",
							width = "full",
							desc = "启用时，若目标在另一个地图区域，则使用旅行路径规划。",
							get = function()
								return Nx.db.profile.Map.RouteUse
							end,
							set = function()
								Nx.db.profile.Map.RouteUse = not Nx.db.profile.Map.RouteUse
							end,				
						},						
						restoreScale = {
							order = 14,
							type = "toggle",							
							name = "追踪完成后恢复地图缩放",
							width = "full",
							desc = "启用时，追踪完成后将恢复地图为之前的缩放。",
							get = function()
								return Nx.db.profile.Map.RestoreScaleAfterTrack
							end,
							set = function()
								Nx.db.profile.Map.RestoreScaleAfterTrack = not Nx.db.profile.Map.RestoreScaleAfterTrack
							end,				
						},				
						spacer3 = {
							order = 15,
							type = "description",
							name = "\n",
						},				
						showTrail = {
							order = 16,
							type = "toggle",							
							name = "显示移动轨迹",
							width = "full",
							desc = "启用时，在地图上绘制出你的移动轨迹。",
							get = function()
								return Nx.db.profile.Map.ShowTrail
							end,
							set = function()
								Nx.db.profile.Map.ShowTrail = not Nx.db.profile.Map.ShowTrail
							end,				
						},									
						trailDist = {
							order = 17,
							type = "range",							
							name = "移动轨迹点间隔",
							desc = "设置轨迹点的间隔",
							min = .1,
							max = 20,
							step = .1,
							bigStep = .1,
							get = function()
								return Nx.db.profile.Map.TrailDist
							end,
							set = function(info,value)
								Nx.db.profile.Map.TrailDist = value
							end,				
						},
						trailCnt = {
							order = 18,
							type = "range",							
							name = "移动轨迹点数量",
							desc = "设置地图上同时存在的最大轨迹点数目",
							min = 0,
							max = 1000,
							step = 10,
							bigStep = 10,
							get = function()
								return Nx.db.profile.Map.TrailCnt
							end,
							set = function(info,value)
								Nx.db.profile.Map.TrailCnt = value
							end,				
						},				
						trailTime = {
							order = 19,
							type = "range",							
							name = "移动轨迹淡出时间",							
							desc = "设置在多少秒后轨迹淡出",
							min = 0,
							max = 1000,
							step = 10,
							bigStep = 10,
							get = function()
								return Nx.db.profile.Map.TrailTime
							end,
							set = function(info,value)
								Nx.db.profile.Map.TrailTime = value
							end,				
						},						
						spacer4 = {
							order = 20,
							type = "description",
							name = "\n",
						},					
						showToolBar = {
							order = 21,
							type = "toggle",							
							name = "显示地图工具栏",
							width = "full",
							desc = "启用时，将在地图上显示工具栏",
							get = function()
								return Nx.db.profile.Map.ShowToolBar
							end,
							set = function()
								Nx.db.profile.Map.ShowToolBar = not Nx.db.profile.Map.ShowToolBar
								Nx.Opts:NXCmdMapToolBarUpdate()
							end,				
						},
						TooltipAnchor = {
							order = 22,
							type	= "select",
							name	= "  地图鼠标提示锚点",
							desc	= "设置地图上鼠标提示窗口的锚点",
							get	= function()
								local vals = Nx.Opts:CalcChoices("Anchor0")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.LocTipAnchor) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("Anchor0")
								Nx.db.profile.Map.LocTipAnchor = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("Anchor0")
							end,
						},
						TooltipAnchorRel = {
							order = 23,
							type	= "select",
							name	= "  地图鼠标提示副锚点",
							desc	= "设置地图上鼠标提示窗口的副锚点",
							get	= function()
								local vals = Nx.Opts:CalcChoices("Anchor0")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.LocTipAnchorRel) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("Anchor0")
								Nx.db.profile.Map.LocTipAnchorRel = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("Anchor0")
							end,
						},		
						TopToolTip = {
							order = 24,
							type = "toggle",							
							name = "鼠标提示置顶",
							width = "full",
							desc = "启用时，地图上的鼠标提示窗口将会出现在最顶层。",
							get = function()
								return Nx.db.profile.Map.TopTooltip
							end,
							set = function()
								Nx.db.profile.Map.TopTooltip = not Nx.db.profile.Map.TopTooltip								
							end,				
						},				
						showTitleName = {
							order = 25,
							type = "toggle",							
							name = "显示地图名称",							
							desc = "启用时, 将在标题栏显示当前地图区域.",
							get = function()
								return Nx.db.profile.Map.ShowTitleName
							end,
							set = function()
								Nx.db.profile.Map.ShowTitleName = not Nx.db.profile.Map.ShowTitleName
							end,				
						},
						showTitleXY = {
							order = 26,
							type = "toggle",							
							name = "显示坐标",							
							desc = "启用时，将在标题栏显示当前坐标.",
							get = function()
								return Nx.db.profile.Map.ShowTitleXY
							end,
							set = function()
								Nx.db.profile.Map.ShowTitleXY = not Nx.db.profile.Map.ShowTitleXY
							end,				
						},
						showTitleSpeed = {
							order = 27,
							type = "toggle",							
							name = "显示速度",							
							desc = "启用时，将在标题栏显示当前移动速度.",
							get = function()
								return Nx.db.profile.Map.ShowTitleSpeed
							end,
							set = function()
								Nx.db.profile.Map.ShowTitleSpeed = not Nx.db.profile.Map.ShowTitleSpeed
							end,				
						},
						showTitle2 = {
							order = 28,
							type = "toggle",							
							name = "显示第二行地图信息",
							width = "full",
							desc = "启用时，显示第二行信息：区域争夺状态/详细区域名称 (需要重载界面)",
							get = function()
								return Nx.db.profile.Map.ShowTitle2
							end,
							set = function()
								Nx.db.profile.Map.ShowTitle2 = not Nx.db.profile.Map.ShowTitle2
								Nx.Opts.NXCmdReload()
							end,				
						},						
						spacer5 = {
							order = 29,
							type = "description",
							name = "\n",
						},									
						showPOI = {
							order = 30,
							type = "toggle",							
							name = "显示关注点",
							width = "full",
							desc = "启用时，在地图上绘制关注点。",
							get = function()
								return Nx.db.profile.Map.ShowPOI
							end,
							set = function()
								Nx.db.profile.Map.ShowPOI = not Nx.db.profile.Map.ShowPOI								
							end,				
						},									
						spacer6 = {
							order = 31,
							type = "description",
							name = "\n",
						},															
						plyrArrowSize = {
							order = 32,
							type = "range",							
							name = "玩家箭头大小",							
							width = "double",
							desc = "设置地图上表示玩家的箭头尺寸。",
							min = 10,
							max = 100,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.Map.PlyrArrowSize
							end,
							set = function(info,value)
								Nx.db.profile.Map.PlyrArrowSize = value
							end,				
						},		
						iconScaleMin = {
							order = 33,
							type = "range",	
							width = "double",							
							name = "图标缩放最小值",							
							desc = "设置当地图缩放时图标缩放的最小值 (-1为禁用缩放)",
							min = -1,
							max = 50,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.Map.IconScaleMin
							end,
							set = function(info,value)
								Nx.db.profile.Map.IconScaleMin = value
							end,				
						},		
						mapLineThick = {
							order = 34,
							type = "range",							
							width = "double",
							name = "地图血条宽度",							
							desc = "设置血条宽度 (0为禁用)",
							min = 0,
							max = 10,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.Map.LineThick
							end,
							set = function(info,value)
								Nx.db.profile.Map.LineThick = value
							end,				
						},		
						zoneDrawCnt = {
							order = 35,
							type = "range",							
							width = "double",
							name = "同时绘制的最多区域数",							
							desc = "设置地图上可同时绘制的最多区域数",
							min = 1,
							max = 20,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.Map.ZoneDrawCnt
							end,
							set = function(info,value)
								Nx.db.profile.Map.ZoneDrawCnt = value
							end,				
						},						
						detailSize = {
							order = 36,
							type = "range",							
							name = "细节图形可视区域",							
							width = "double",
							desc = "设置卫星地图模式时的细节图形可视区域 (需要重载界面)",
							min = 2,
							max = 40,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.Map.DetailSize
							end,
							set = function(info,value)
								Nx.db.profile.Map.DetailSize = value
								Nx.Opts.NXCmdReload()								
							end,				
						},					
						spacer7 = {
							order = 37,
							type = "description",
							name = "\n",
						},			
						header = {
							order	= 38,
							type	= "header",
							name	= "地图鼠标按键绑定",
						},						
						ButLAlt = {
							order = 39,
							type	= "select",
							name	= "           Alt-左键",
							desc	= "设置Alt-左键时的地图操作",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButLAlt) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButLAlt = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},		
						ButLCtrl = {
							order = 40,
							type	= "select",
							name	= "           Ctrl-左键",
							desc	= "设置Ctrl-左键时的地图操作",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButLCtrl) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButLCtrl = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},								
						ButM = {
							order = 41,
							type	= "select",
							name	= "           中键点击",
							desc	= "设置中键点击时的地图操作",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButM) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButM = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},								
						ButMAlt = {
							order = 42,
							type	= "select",
							name	= "           Alt-中键",
							desc	= "顾名思义……不翻译了。",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButMAlt) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButMAlt = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},								
						ButMCtrl = {
							order = 43,
							type	= "select",
							name	= "           Ctrl-左键",
							desc	= "顾名思义……不翻译了。",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButMCtrl) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButMCtrl = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},								
						ButR = {
							order = 44,
							type	= "select",
							name	= "           右键点击",
							desc	= "顾名思义……不翻译了。",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButR) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButR = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},								
						ButRAlt = {
							order = 45,
							type	= "select",
							name	= "           Alt-右键",
							desc	= "顾名思义……不翻译了。",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButRAlt) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButRAlt = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},								
						ButRCtrl = {
							order = 46,
							type	= "select",
							name	= "           Ctrl-右键",
							desc	= "顾名思义……不翻译了。",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.ButRCtrl) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.ButRCtrl = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},		
						But4 = {
							order = 47,
							type	= "select",
							name	= "           鼠标按键4点击",
							desc	= "设置点击鼠标按键4（通常为第一个侧键）时的地图操作",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.But4) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.But4 = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},		
						But4Alt = {
							order = 48,
							type	= "select",
							name	= "           Alt-按键4",
							desc	= "设置点击Alt-鼠标按键4时的地图操作",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.But4Alt) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.But4Alt = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},		
						But4Ctrl = {
							order = 49,
							type	= "select",
							name	= "           Ctrl-按键4",
							desc	= "顾名思义。不翻译了。",
							get	= function()
								local vals = Nx.Opts:CalcChoices("MapFunc")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.Map.But4Ctrl) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("MapFunc")
								Nx.db.profile.Map.But4Ctrl = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("MapFunc")
							end,
						},								
					},
				},
				miniMap = {
					type = "group",
					name = "小地图设置",
					order = 2,
					args = {
						MMOwn = {
							order = 1,
							type = "toggle",
							width = "full",
							name = "整合暴雪自带小地图到Carbonite",
							desc = "启用时，Carbonite将整合自带小地图到Carbonite地图 (需要重载界面)",
							get = function()
								return Nx.db.profile.MiniMap.Own
							end,
							set = function()
								Nx.db.profile.MiniMap.Own = not Nx.db.profile.MiniMap.Own
								Nx.Opts:NXCmdMMOwnChange(_,Nx.db.profile.MiniMap.Own)								
							end,				
						},							  						  
						spacer1 = {
							order = 3,
							type = "description",
							name = "\n",
						},			
						MMSquare = {
							order = 4,
							type = "toggle",
							width = "full",
							name = "方形小地图",
							desc = "启用时， Carbonite将会把小地图变成方形",
							get = function()
								return Nx.db.profile.MiniMap.Square
							end,
							set = function()
								Nx.db.profile.MiniMap.Square = not Nx.db.profile.MiniMap.Square								
							end,				
						},
						MMAboveIcons = {
							order = 5,
							type = "toggle",
							width = "full",
							name = "小地图绘制在图标之上",
							desc = "启用时，小地图将会盖住Carbonite地图图标，你需要按住Ctrl观看图标。",
							get = function()
								return Nx.db.profile.MiniMap.AboveIcons
							end,
							set = function()
								Nx.db.profile.MiniMap.AboveIcons = not Nx.db.profile.MiniMap.AboveIcons								
							end,				
						},						
						MMIconScale = {
							order = 6,
							type = "range",							
							name = "小地图图标缩放",														
							desc = "设置Carbonite小型地图图标缩放",
							min = .1,
							max = 10,
							step = .1,
							bigStep = .1,
							get = function()
								return Nx.db.profile.MiniMap.IScale
							end,
							set = function(info,value)
								Nx.db.profile.MiniMap.IScale = value
							end,				
						},					
						MMDockIScale = {
							order = 7,
							type = "range",							
							name = "整合停靠图标缩放",													
							desc = "设置被整合进Carbonite小地图图标的缩放",
							min = .1,
							max = 10,
							step = .1,
							bigStep = .1,
							get = function()
								return Nx.db.profile.MiniMap.DockIScale
							end,
							set = function(info,value)
								Nx.db.profile.MiniMap.DockIScale = value
							end,				
						},					
						
						MMGlow = {
							order = 8,
							type = "range",							
							name = "小地图节点闪烁频率",														
							desc = "设置采集点闪烁的频率 (0为关闭)",
							min = 0,
							max = 4,
							step = .1,
							bigStep = .1,
							get = function()
								return Nx.db.profile.MiniMap.NodeGD
							end,
							set = function(info,value)
								Nx.db.profile.MiniMap.NodeGD = value
								Nx.Opts:NXCmdMMChange()
							end,				
						},						
						spacer2 = {
							order = 9,
							type = "description",
							name = "\n",
						},									
						MMDockAlways = {
							order = 10,
							type = "toggle",
							width = "full",
							name = "始终停靠小地图",
							desc = "启用时，小地图将会一直出现在Carbonite地图的一角",
							get = function()
								return Nx.db.profile.MiniMap.DockAlways
							end,
							set = function()
								Nx.db.profile.MiniMap.DockAlways = not Nx.db.profile.MiniMap.DockAlways								
							end,				
						},				
						MMDockIndoors = {
							order = 11,
							type = "toggle",
							width = "full",
							name = "在室内是停靠小地图",
							desc = "启用时，当你在室内时小地图将会一直出现在Carbonite地图的一角",
							get = function()
								return Nx.db.profile.MiniMap.DockIndoors
							end,
							set = function()
								Nx.db.profile.MiniMap.DockIndoors = not Nx.db.profile.MiniMap.DockIndoors
							end,				
						},												
						MMDockBugged = {
							order = 12,
							type = "toggle",
							width = "full",
							name = "错误区域停靠小地图",
							desc = "启用时，当你在透明度错误区域时将自动停靠小地图 (黑色小地图)",
							get = function()
								return Nx.db.profile.MiniMap.DockBugged
							end,
							set = function()
								Nx.db.profile.MiniMap.DockBugged = not Nx.db.profile.MiniMap.DockBugged
							end,				
						},						
						MMDockOnMax = {
							order = 13,
							type = "toggle",
							width = "full",
							name = "大型地图时停靠",
							desc = "启用时，当你开启Carbonite大地图时小地图将停靠。",
							get = function()
								return Nx.db.profile.MiniMap.DockOnMax
							end,
							set = function()
								Nx.db.profile.MiniMap.DockOnMax = not Nx.db.profile.MiniMap.DockOnMax								
							end,				
						},		
						MMHideOnMax = {
							order = 14,
							type = "toggle",
							width = "full",
							name = "大型地图时隐藏",
							desc = "启用时，当你开启Carbonite大地图时小地图将隐藏。",
							get = function()
								return Nx.db.profile.MiniMap.HideOnMax
							end,
							set = function()
								Nx.db.profile.MiniMap.HideOnMax = not Nx.db.profile.MiniMap.HideOnMax
							end,				
						},						
						
						MMDockSquare = {
							order = 15,
							type = "toggle",
							width = "full",
							name = "停靠式小地图为方形",
							desc = "启用时，停靠式小地图将变成方形。",
							get = function()
								return Nx.db.profile.MiniMap.DockSquare
							end,
							set = function()
								Nx.db.profile.MiniMap.DockSquare = not Nx.db.profile.MiniMap.DockSquare
							end,				
						},						
						MMDockBottom = {
							order = 16,
							type = "toggle",
							width = "full",
							name = "小地图停靠在底部",
							desc = "启用时，小地图停靠在底部。",
							get = function()
								return Nx.db.profile.MiniMap.DockBottom
							end,
							set = function()
								Nx.db.profile.MiniMap.DockBottom = not Nx.db.profile.MiniMap.DockBottom
							end,				
						},						
						MMDockRight = {
							order = 17,
							type = "toggle",
							width = "full",
							name = "小地图停靠在右侧",
							desc = "启用时，小地图停靠在右侧。",
							get = function()
								return Nx.db.profile.MiniMap.DockRight
							end,
							set = function()
								Nx.db.profile.MiniMap.DockRight = not Nx.db.profile.MiniMap.DockRight
							end,				
						},										
						MMDXO = {
							order = 18,
							type = "range",							
							name = "小地图停靠X偏移量",														
							desc = "设置小地图停靠X偏移量",
							min = 0,
							max = 200,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.MiniMap.DXO
							end,
							set = function(info,value)
								Nx.db.profile.MiniMap.DXO = value
							end,				
						},					
						MMDYO = {
							order = 19,
							type = "range",							
							name = "小地图停靠Y偏移量",														
							desc = "设置小地图停靠Y偏移量",
							min = 0,
							max = 200,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.MiniMap.DYO
							end,
							set = function(info,value)
								Nx.db.profile.MiniMap.DYO = value
							end,				
						},
						MMIndoorTogFullSize = {
							order = 20,
							type = "toggle",
							width = "full",
							name = "室内时使用全尺寸小地图",
							desc = "启用时，室内时小地图将最大化。",
							get = function()
								return Nx.db.profile.MiniMap.IndoorTogFullSize
							end,
							set = function()
								Nx.db.profile.MiniMap.IndoorTogFullSize = not Nx.db.profile.MiniMap.IndoorTogFullSize
							end,				
						},
						MMDockBuggedTogFullSize = {
							order = 21,
							type = "toggle",
							width = "full",
							name = "错误区域时使用全尺寸小地图",
							desc = "启用时，透明度错误区域小地图将最大化。",
							get = function()
								return Nx.db.profile.MiniMap.BuggedTogFullSize
							end,
							set = function()
								Nx.db.profile.MiniMap.BuggedTogFullSize = not Nx.db.profile.MiniMap.BuggedTogFullSize
							end,				
						},
						MMDockInstanceTogFullSize = {
							order = 22,
							type = "toggle",
							width = "full",
							name = "副本内小地图最大化",
							desc = "启用时， 当你在副本内时小地图将最大化。",
							get = function()
								return Nx.db.profile.MiniMap.InstanceTogFullSize
							end,
							set = function()
								Nx.db.profile.MiniMap.InstanceTogFullSize = not Nx.db.profile.MiniMap.InstanceTogFullSize
							end,				
						},
						MMMoveCapBars = {
							order = 23,
							type = "toggle",
							width = "full",
							name = "夺取进度条显示在地图下方",
							desc = "启用时，夺取进度条将显示在地图下方。",
							get = function()
								return Nx.db.profile.MiniMap.MoveCapBars
							end,
							set = function()
								Nx.db.profile.MiniMap.MoveCapBars = not Nx.db.profile.MiniMap.MoveCapBars
							end,				
						},
						MMShowOldNameplate = {
							order = 24,
							type = "toggle",
							width = "full",
							name = "启用原始姓名版",
							desc = "启用时，小地图将使用原始姓名版。",
							get = function()
								return Nx.db.profile.MiniMap.ShowOldNameplate
							end,
							set = function()
								Nx.db.profile.MiniMap.ShowOldNameplate = not Nx.db.profile.MiniMap.ShowOldNameplate
								Nx.Opts:NXCmdMMButUpdate()
							end,				
						},						
					},
				},	
				buttonFrame = {
					type = "group",
					name = "小地图按钮设置",
					order = 3,
					args = {
						MMButOwn = {
							order = 1,
							type = "toggle",
							width = "full",
							name = "将小地图按钮移动到Carbonite按钮窗口",
							desc = "启用时，小地图按钮会移动到Carbonite按钮窗口，在点击Carbonite图标时出现 (需要重载界面)",
							get = function()
								return Nx.db.profile.MiniMap.ButOwn
							end,
							set = function()
								Nx.db.profile.MiniMap.ButOwn = not Nx.db.profile.MiniMap.ButOwn
								Nx.Opts:NXCmdReload()
							end,				
						},			
						spacer1 = {
							order = 3,
							type = "description",
							name = "\n",
						},
						MMButHide = {
							order = 4,
							type = "toggle",
							width = "full",
							name = "隐藏小地图按钮窗口",
							desc = "启用时隐藏小地图按钮窗口",
							get = function()
								return Nx.db.profile.MiniMap.ButHide
							end,
							set = function()
								Nx.db.profile.MiniMap.ButHide = not Nx.db.profile.MiniMap.ButHide								
								Nx.Window:SetAttribute("NxMapDock","H",Nx.db.profile.MiniMap.ButHide)
							end,				
						},
						MMButLock = {
							order = 5,
							type = "toggle",
							width = "full",
							name = "锁定小地图按钮窗口",
							desc = "启用时锁定小地图按钮窗口",
							get = function()
								return Nx.db.profile.MiniMap.ButLock
							end,
							set = function()
								Nx.db.profile.MiniMap.ButLock = not Nx.db.profile.MiniMap.ButLock
								Nx.Window:SetAttribute("NxMapDock","L",Nx.db.profile.MiniMap.ButLock)
							end,				
						},
						spacer2 = {
							order = 6,
							type = "description",
							name = "\n",
						},		
						MMButColumns = {
							order = 7,
							type = "range",							
							name = "小地图按钮列数",													
							width = "double",
							desc = "设置小地图按钮列数",
							min = 1,
							max = 10,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.MiniMap.ButColumns
							end,
							set = function(info,value)
								Nx.db.profile.MiniMap.ButColumns = value
							end,				
						},					
						MMButSpacing = {
							order = 8,
							type = "range",							
							name = "小地图按钮间隔",	
							width = "double",
							desc = "设置小地图按钮间隔",
							min = 25,
							max = 90,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.MiniMap.ButSpacing
							end,
							set = function(info,value)
								Nx.db.profile.MiniMap.ButSpacing = value
							end,				
						},				
						ButCorner = {
							order = 9,
							type	= "select",
							name	= "首个按钮位置",
							desc	= "设置首个按钮位于窗口的哪个角",
							get	= function()
								local vals = Nx.Opts:CalcChoices("Corner")
								for a,b in pairs(vals) do
								  if (b == Nx.db.profile.MiniMap.ButCorner) then
									 return a
								  end
								end
								return ""
							end,
							set	= function(info, name)
								local vals = Nx.Opts:CalcChoices("Corner")
								Nx.db.profile.MiniMap.ButCorner = vals[name]								
							end,
							values	= function()
								return Nx.Opts:CalcChoices("Corner")
							end,
						},						
						spacer3 = {
							order = 10,
							type = "description",
							name = "\n",
						},		
						MMButShowCarb = {
							order = 11,
							type = "toggle",
							width = "full",
							name = "启用Carbonite小地图按钮",
							desc = "在按钮窗口添加Carbonite按钮",
							get = function()
								return Nx.db.profile.MiniMap.ButShowCarb
							end,
							set = function()
								Nx.db.profile.MiniMap.ButShowCarb = not Nx.db.profile.MiniMap.ButShowCarb
								Nx.Opts:NXCmdMMButUpdate()
							end,
						},
						MMButShowCalendar = {
							order = 12,
							type = "toggle",
							width = "full",
							name = "启用日历按钮",
							desc = "在按钮窗口显示日历按钮",
							get = function()
								return Nx.db.profile.MiniMap.ButShowCalendar
							end,
							set = function()
								Nx.db.profile.MiniMap.ButShowCalendar = not Nx.db.profile.MiniMap.ButShowCalendar
								Nx.Opts:NXCmdMMButUpdate()
							end,
						},
						MMButShowClock = {
							order = 13,
							type = "toggle",
							width = "full",
							name = "启用时钟按钮",
							desc = "在按钮窗口显示时钟按钮",
							get = function()
								return Nx.db.profile.MiniMap.ButShowClock
							end,
							set = function()
								Nx.db.profile.MiniMap.ButShowClock = not Nx.db.profile.MiniMap.ButShowClock
								Nx.Opts:NXCmdMMButUpdate()
							end,
						},
						MMButShowWorldMap = {
							order = 14,
							type = "toggle",
							width = "full",
							name = "启用世界地图按钮",
							desc = "在按钮窗口显示世界地图按钮",
							get = function()
								return Nx.db.profile.MiniMap.ButShowWorldMap
							end,
							set = function()
								Nx.db.profile.MiniMap.ButShowWorldMap = not Nx.db.profile.MiniMap.ButShowWorldMap
								Nx.Opts:NXCmdMMButUpdate()
							end,
						},						
					},	
				},
			},
		}
	end
	return map
end

local font
local function fontConfig()
	if not font then	
		font = {
			type = "group",
			name = "字体选项",
			args = {	
				SmallFont = {
					order = 1,
					type	= "select",
					name	= "小字体",
					desc	= "设置小号文字显示的字体",
					get	= function()
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.Font.Small) then
							 return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						Nx.db.profile.Font.Small = vals[name]						
						Nx.Opts:NXCmdFontChange()
					end,
					values	= function()
						return Nx.Opts:CalcChoices("FontFace","Get")
					end,					
				},
				SmallFontSize = {
					order = 2,
					type = "range",							
					name = "小字体大小",						
					desc = "设置小字字体的大小",
					min = 6,
					max = 14,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.SmallSize
					end,
					set = function(info,value)
						Nx.db.profile.Font.SmallSize = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},		
				SmallFontSpacing = {
					order = 3,
					type = "range",							
					name = "小字体间距",						
					desc = "设置小字字体间距",
					min = -10,
					max = 20,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.SmallSpacing
					end,
					set = function(info,value)
						Nx.db.profile.Font.SmallSpacing = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},		
				MediumFont = {
					order = 4,
					type	= "select",
					name	= "中字体",
					desc	= "设置常规文字显示的字体",
					get	= function()
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.Font.Medium) then
							 return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						Nx.db.profile.Font.Medium = vals[name]	
						Nx.Opts:NXCmdFontChange()
					end,
					values	= function()
						return Nx.Opts:CalcChoices("FontFace","Get")
					end,					
				},
				MediumFontSize = {
					order = 5,
					type = "range",							
					name = "中字体大小",						
					desc = "设置常规字体大小",
					min = 6,
					max = 20,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MediumSize
					end,
					set = function(info,value)
						Nx.db.profile.Font.MediumSize = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},		
				MediumFontSpacing = {
					order = 6,
					type = "range",							
					name = "中字体间距",						
					desc = "设置常规字体间距",
					min = -10,
					max = 20,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MediumSpacing
					end,
					set = function(info,value)
						Nx.db.profile.Font.MediumSpacing = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},					
				MapFont = {
					order = 7,
					type	= "select",
					name	= "地图字体",
					desc	= "设置地图中显示的字体",
					get	= function()
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.Font.Map) then
							 return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						Nx.db.profile.Font.Map = vals[name]	
						Nx.Opts:NXCmdFontChange()
					end,
					values	= function()
						return Nx.Opts:CalcChoices("FontFace","Get")
					end,					
				},
				MapFontSize = {
					order = 8,
					type = "range",							
					name = "地图字体大小",						
					desc = "设置地图字体的大小",
					min = 6,
					max = 14,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MapSize
					end,
					set = function(info,value)
						Nx.db.profile.Font.MapSize = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},		
				MapFontSpacing = {
					order = 9,
					type = "range",							
					name = "地图字体间距",						
					desc = "设置地图字体的间距",
					min = -10,
					max = 20,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MapSpacing
					end,
					set = function(info,value)
						Nx.db.profile.Font.MapSpacing = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},									
				spacer = {
					type = "description",
					name = "",
					order = 10,
				},
				MapLocFont = {
					order = 11,
					type	= "select",
					name	= "地图位置工具条字体",
					desc	= "设置地图位置工具条字体",
					get	= function()
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.Font.MapLoc) then
							 return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						Nx.db.profile.Font.MapLoc = vals[name]	
						Nx.Opts:NXCmdFontChange()
					end,
					values	= function()
						return Nx.Opts:CalcChoices("FontFace","Get")
					end,					
				},
				MapLocFontSize = {
					order = 12,
					type = "range",							
					name = "地图位置工具条字体大小",						
					desc = "设置地图位置工具条字体大小",
					min = 6,
					max = 14,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MapLocSize
					end,
					set = function(info,value)
						Nx.db.profile.Font.MapLocSize = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},
				MapLocFontSpacing = {
					order = 13,
					type = "range",							
					name = "地图位置工具条字体间距",						
					desc = "设置地图位置工具条字体间距",
					min = -10,
					max = 20,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MapLocSpacing
					end,
					set = function(info,value)
						Nx.db.profile.Font.MapLocSpacing = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},									
				spacer2 = {
					type = "description",
					name = "",
					order = 14,
				},				
				MenuFont = {
					order = 15,
					type	= "select",
					name	= "菜单字体",
					desc	= "设置菜单中显示的字体",
					get	= function()
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.Font.Menu) then
							 return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("FontFace","Get")
						Nx.db.profile.Font.Menu = vals[name]	
						Nx.Opts:NXCmdFontChange()
					end,
					values	= function()
						return Nx.Opts:CalcChoices("FontFace","Get")
					end,					
				},
				MenuFontSize = {
					order = 16,
					type = "range",							
					name = "菜单字体大小",						
					desc = "设置菜单字体的大小",
					min = 6,
					max = 14,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MenuSize
					end,
					set = function(info,value)
						Nx.db.profile.Font.MenuSize = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},				
				MenuFontSpacing = {
					order = 17,
					type = "range",							
					name = "菜单字间距",						
					desc = "设置菜单字体的间距",
					min = -10,
					max = 20,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Font.MenuSpacing
					end,
					set = function(info,value)
						Nx.db.profile.Font.MenuSpacing = value
						Nx.Opts:NXCmdFontChange()
					end,				
				},									
			},
		}
	end
	return font
end

local guidegather
local function guidegatherConfig ()
	if not guidegather then
		guidegather = {
			type = "group",
			name = "百科指南选项",
			childGroups	= "tab",
			args = {
				guideOpts = {
					type = "group",
					name = "百科指南选项",
					order = 1,
					args = {
						GuideVendorVMax = {
							order = 1,
							type = "range",							
							name = "最大商人记录数量",						
							desc = "设置商人记录的最大数量以便于在百科指南中查看",
							min = 0,
							max = 100,
							step = 1,
							bigStep = 1,
							get = function()
								return Nx.db.profile.Guide.VendorVMax
							end,
							set = function(info,value)
								Nx.db.profile.Guide.VendorVMax = value								
							end,				
						},						
					},
				},
				gatherOpts = {
					type = "group",
					name = "采集选项",
					order = 2,
					args = {
						gatherEnable = {						
							order = 1,
							type = "toggle",
							width = "full",
							name = "启用采集数据保存",
							desc = "启用时, 将记录所有采集到的资源的位置",
							get = function()
								return Nx.db.profile.Guide.GatherEnabled
							end,
							set = function()
								Nx.db.profile.Guide.GatherEnabled = not Nx.db.profile.Guide.GatherEnabled								
							end,							
						},
						spacer1 = {
							order = 2,
							type = "description",
							name = "\n",
						},			
						CmdDelHerb = {
							order = 3,
							type = "execute",
							width = "full",
							name = "删除草药采集位置",
							func = function ()
								Nx.Opts:NXCmdDeleteHerb()
							end,
						},
						CmdDelMine = {
							order = 4,
							type = "execute",
							width = "full",
							name = "删除矿点采集位置",
							func = function ()
								Nx.Opts:NXCmdDeleteMine()
							end,
						},						
						CmdDelMisc = {
							order = 5,
							type = "execute",
							width = "full",
							name = "删除杂项采集位置",
							func = function ()
								Nx.Opts:NXCmdDeleteMisc()
							end,
						},						
						spacer2 = {
							order = 2,
							type = "description",
							name = "\n",
						},								
						CmdImportHerb = {
							order = 7,
							type = "execute",
							width = "full",
							name = "从GatherMate2_Data导入草药",
							func = function ()
								Nx.Opts:NXCmdImportCarbHerb()
							end,
						},						
						CmdImportMine = {
							order = 8,
							type = "execute",
							width = "full",
							name = "从GatherMate2_Data导入矿石",
							func = function ()
								Nx.Opts:NXCmdImportCarbMine()
							end,
						},						
						CmdImportMisc = {
							order = 9,
							type = "execute",
							width = "full",
							name = "从GatherMate2_Data导入杂项",
							func = function ()
								Nx.Opts:NXCmdImportCarbMisc()
							end,
						},												
					},					
				},
				HerbDisp = {
					type = "group",
					name = "草药采集点",
					order = 3,
					args = {
						anclich = {						
							order = 1,
							type = "toggle",
							width = "full",
							name = "远古苔", --Rythal你把Ancient写成Anchient了知不知道...
							desc = "在地图上显示远古苔采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[1] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[1] = not Nx.db.profile.Guide.ShowHerbs[1]								
							end,							
						},
						arthastear = {						
							order = 2,
							type = "toggle",
							width = "full",
							name = "阿尔萨斯之泪",
							desc = "在地图上显示阿尔萨斯之泪采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[2] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[2] = not Nx.db.profile.Guide.ShowHerbs[2]								
							end,							
						},						
						blacklotus = {						
							order = 3,
							type = "toggle",
							width = "full",
							name = "黑莲花",
							desc = "在地图上显示黑莲花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[3] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[3] = not Nx.db.profile.Guide.ShowHerbs[3]								
							end,							
						},		
						blindweed = {						
							order = 4,
							type = "toggle",
							width = "full",
							name = "盲目草",
							desc = "在地图上显示盲目草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[4] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[4] = not Nx.db.profile.Guide.ShowHerbs[4]								
							end,							
						},
						bloodthistle = {						
							order = 5,
							type = "toggle",
							width = "full",
							name = "血蓟",
							desc = "在地图上显示血蓟采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[5] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[5] = not Nx.db.profile.Guide.ShowHerbs[5]								
							end,							
						},
						briarthorn = {						
							order = 6,
							type = "toggle",
							width = "full",
							name = "荆棘草",
							desc = "在地图上显示荆棘草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[6] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[6] = not Nx.db.profile.Guide.ShowHerbs[6]
							end,							
						},						
						bruiseweed = {						
							order = 7,
							type = "toggle",
							width = "full",
							name = "跌打草",
							desc = "在地图上显示跌打草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[7] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[7] = not Nx.db.profile.Guide.ShowHerbs[7]								
							end,							
						},						
						dreamfoil = {						
							order = 8,
							type = "toggle",
							width = "full",
							name = "梦叶草",
							desc = "在地图上显示梦叶草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[8] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[8] = not Nx.db.profile.Guide.ShowHerbs[8]								
							end,							
						},						
						dreamglory = {						
							order = 9,
							type = "toggle",
							width = "full",
							name = "梦露花",
							desc = "在地图上显示梦露花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[9] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[9] = not Nx.db.profile.Guide.ShowHerbs[9]								
							end,							
						},						
						earthroot = {						
							order = 10,
							type = "toggle",
							width = "full",
							name = "地根草",
							desc = "在地图上显示地根草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[10] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[10] = not Nx.db.profile.Guide.ShowHerbs[10]								
							end,							
						},						
						fadeleaf = {						
							order = 11,
							type = "toggle",
							width = "full",
							name = "枯叶草",
							desc = "在地图上显示枯叶草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[11] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[11] = not Nx.db.profile.Guide.ShowHerbs[11]								
							end,							
						},						
						felweed = {						
							order = 12,
							type = "toggle",
							width = "full",
							name = "魔草",
							desc = "在地图上显示魔草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[12] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[12] = not Nx.db.profile.Guide.ShowHerbs[12]								
							end,							
						},						
						firebloom = {						
							order = 13,
							type = "toggle",
							width = "full",
							name = "火焰花",
							desc = "在地图上显示火焰花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[13] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[13] = not Nx.db.profile.Guide.ShowHerbs[13]								
							end,							
						},						
						flamecap = {						
							order = 14,
							type = "toggle",
							width = "full",
							name = "烈焰菇",
							desc = "在地图上显示烈焰菇采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[14] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[14] = not Nx.db.profile.Guide.ShowHerbs[14]								
							end,							
						},						
						ghostmush = {						
							order = 15,
							type = "toggle",
							width = "full",
							name = "幽灵菇",
							desc = "在地图上显示幽灵菇采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[15] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[15] = not Nx.db.profile.Guide.ShowHerbs[15]								
							end,							
						},						
						goldsansam = {						
							order = 16,
							type = "toggle",
							width = "full",
							name = "黄金参",
							desc = "在地图上显示黄金参采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[16] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[16] = not Nx.db.profile.Guide.ShowHerbs[16]								
							end,							
						},						
						goldthorn = {						
							order = 17,
							type = "toggle",
							width = "full",
							name = "金棘草",
							desc = "在地图上显示金棘草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[17] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[17] = not Nx.db.profile.Guide.ShowHerbs[17]								
							end,							
						},						
						gravemoss = {						
							order = 18,
							type = "toggle",
							width = "full",
							name = "墓地苔",
							desc = "在地图上显示墓地苔采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[18] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[18] = not Nx.db.profile.Guide.ShowHerbs[18]								
							end,							
						},						
						gromsblood = {						
							order = 19,
							type = "toggle",
							width = "full",
							name = "格罗姆之血",
							desc = "在地图上显示格罗姆之血采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[19] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[19] = not Nx.db.profile.Guide.ShowHerbs[19]								
							end,							
						},						
						icecap = {						
							order = 20,
							type = "toggle",
							width = "full",
							name = "冰盖草",
							desc = "在地图上显示冰盖草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[20] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[20] = not Nx.db.profile.Guide.ShowHerbs[20]								
							end,							
						},						
						khadgar = {						
							order = 21,
							type = "toggle",
							width = "full",
							name = "卡德加的胡须",
							desc = "在地图上显示卡德加的胡须采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[21] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[21] = not Nx.db.profile.Guide.ShowHerbs[21]								
							end,							
						},						
						kingsblood = {						
							order = 22,
							type = "toggle",
							width = "full",
							name = "皇血草",
							desc = "在地图上显示皇血草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[22] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[22] = not Nx.db.profile.Guide.ShowHerbs[22]								
							end,							
						},												
						liferoot = {						
							order = 23,
							type = "toggle",
							width = "full",
							name = "活根草",
							desc = "在地图上显示活根草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[23] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[23] = not Nx.db.profile.Guide.ShowHerbs[23]								
							end,							
						},												
						mageroyal = {						
							order = 24,
							type = "toggle",
							width = "full",
							name = "魔皇草",
							desc = "在地图上显示魔皇草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[24] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[24] = not Nx.db.profile.Guide.ShowHerbs[24]								
							end,							
						},												
						manathistle = {						
							order = 25,
							type = "toggle",
							width = "full",
							name = "法力蓟",
							desc = "在地图上显示法力蓟采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[25] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[25] = not Nx.db.profile.Guide.ShowHerbs[25]								
							end,							
						},												
						mountainsilver = {						
							order = 26,
							type = "toggle",
							width = "full",
							name = "山鼠草",
							desc = "在地图上显示山鼠草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[26] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[26] = not Nx.db.profile.Guide.ShowHerbs[26]								
							end,							
						},												
						netherbloom = {						
							order = 27,
							type = "toggle",
							width = "full",
							name = "虚空花",
							desc = "在地图上显示虚空花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[27] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[27] = not Nx.db.profile.Guide.ShowHerbs[27]								
							end,							
						},												
						netherdust = {						
							order = 28,
							type = "toggle",
							width = "full",
							name = "灵尘灌木丛",
							desc = "在地图上显示灵尘灌木丛采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[28] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[28] = not Nx.db.profile.Guide.ShowHerbs[28]								
							end,							
						},
						nightmare = {						
							order = 29,
							type = "toggle",
							width = "full",
							name = "噩梦藤",
							desc = "在地图上显示噩梦藤采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[29] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[29] = not Nx.db.profile.Guide.ShowHerbs[29]								
							end,							
						},						
						peacebloom = {						
							order = 30,
							type = "toggle",
							width = "full",
							name = "宁神花",
							desc = "在地图上显示宁神花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[30] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[30] = not Nx.db.profile.Guide.ShowHerbs[30]								
							end,							
						},						
						sorrowmoss = {						
							order = 31,
							type = "toggle",
							width = "full",
							name = "哀伤苔",
							desc = "在地图上显示哀伤苔采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[31] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[31] = not Nx.db.profile.Guide.ShowHerbs[31]								
							end,							
						},						
						purplelotus = {						
							order = 32,
							type = "toggle",
							width = "full",
							name = "紫莲花",
							desc = "在地图上显示紫莲花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[32] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[32] = not Nx.db.profile.Guide.ShowHerbs[32]								
							end,							
						},						
						ragveil = {						
							order = 33,
							type = "toggle",
							width = "full",
							name = "邪雾草",
							desc = "在地图上显示邪雾草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[33] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[33] = not Nx.db.profile.Guide.ShowHerbs[33]								
							end,							
						},						
						silverleaf = {						
							order = 34,
							type = "toggle",
							width = "full",
							name = "银叶草",
							desc = "在地图上显示银叶草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[34] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[34] = not Nx.db.profile.Guide.ShowHerbs[34]								
							end,							
						},						
						stranglekelp = {						
							order = 35,
							type = "toggle",
							width = "full",
							name = "荆棘藻",
							desc = "在地图上显示荆棘藻采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[35] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[35] = not Nx.db.profile.Guide.ShowHerbs[35]								
							end,							
						},						
						sungrass = {						
							order = 36,
							type = "toggle",
							width = "full",
							name = "太阳草",
							desc = "在地图上显示太阳草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[36] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[36] = not Nx.db.profile.Guide.ShowHerbs[36]								
							end,							
						},						
						terocone = {						
							order = 37,
							type = "toggle",
							width = "full",
							name = "泰罗果",
							desc = "在地图上显示泰罗果采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[37] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[37] = not Nx.db.profile.Guide.ShowHerbs[37]								
							end,							
						},						
						wildsteel = {						
							order = 38,
							type = "toggle",
							width = "full",
							name = "野钢花",
							desc = "在地图上显示野钢花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[38] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[38] = not Nx.db.profile.Guide.ShowHerbs[38]								
							end,							
						},						
						dragonsteeth = {						
							order = 39,
							type = "toggle",
							width = "full",
							name = "龙齿草", --冬刺草居然在CTM改名了哎
							desc = "在地图上显示龙齿草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[39] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[39] = not Nx.db.profile.Guide.ShowHerbs[39]								
							end,							
						},
						glowcap = {						
							order = 40,
							type = "toggle",
							width = "full",
							name = "亮顶蘑菇", --有意思吗这个都写上？
							desc = "在地图上显示亮顶蘑菇采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[40] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[40] = not Nx.db.profile.Guide.ShowHerbs[40]								
							end,							
						},												
						goldclover = {						
							order = 41,
							type = "toggle",
							width = "full",
							name = "金苜蓿",
							desc = "在地图上显示金苜蓿采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[41] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[41] = not Nx.db.profile.Guide.ShowHerbs[41]								
							end,							
						},												
						talandrarose = {						
							order = 42,
							type = "toggle",
							width = "full",
							name = "塔兰德拉的玫瑰",
							desc = "在地图上显示塔兰德拉的玫瑰采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[42] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[42] = not Nx.db.profile.Guide.ShowHerbs[42]								
							end,							
						},												
						adderstongue = {						
							order = 43,
							type = "toggle",
							width = "full",
							name = "蛇信草",
							desc = "在地图上显示蛇信草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[43] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[43] = not Nx.db.profile.Guide.ShowHerbs[43]								
							end,							
						},												
						frozenherb = {						
							order = 44,
							type = "toggle",
							width = "full",
							name = "冰冷的草药",
							desc = "在地图上显示冰冷的草药采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[44] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[44] = not Nx.db.profile.Guide.ShowHerbs[44]								
							end,							
						},												
						tigerlily = {						
							order = 45,
							type = "toggle",
							width = "full",
							name = "卷丹",
							desc = "在地图上显示卷丹采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[45] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[45] = not Nx.db.profile.Guide.ShowHerbs[45]								
							end,							
						},												
						lichbloom = {						
							order = 46,
							type = "toggle",
							width = "full",
							name = "巫妖花",
							desc = "在地图上显示巫妖花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[46] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[46] = not Nx.db.profile.Guide.ShowHerbs[46]								
							end,							
						},												
						icethorn = {						
							order = 47,
							type = "toggle",
							width = "full",
							name = "冰棘草",
							desc = "在地图上显示冰棘草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[47] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[47] = not Nx.db.profile.Guide.ShowHerbs[47]								
							end,							
						},												
						frostlotus = {						
							order = 48,
							type = "toggle",
							width = "full",
							name = "雪莲花",
							desc = "在地图上显示雪莲花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[48] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[48] = not Nx.db.profile.Guide.ShowHerbs[48]								
							end,							
						},												
						firethorn = {						
							order = 49,
							type = "toggle",
							width = "full",
							name = "火棘花",
							desc = "在地图上显示火棘花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[49] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[49] = not Nx.db.profile.Guide.ShowHerbs[49]								
							end,							
						},												
						azsharaveil = {						
							order = 50,
							type = "toggle",
							width = "full",
							name = "艾萨拉雾菇",
							desc = "在地图上显示艾萨拉雾菇采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[50] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[50] = not Nx.db.profile.Guide.ShowHerbs[50]								
							end,							
						},												
						cinderbloom = {						
							order = 51,
							type = "toggle",
							width = "full",
							name = "燃烬草",
							desc = "在地图上显示燃烬草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[51] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[51] = not Nx.db.profile.Guide.ShowHerbs[51]								
							end,							
						},												
						stormvine = {						
							order = 52,
							type = "toggle",
							width = "full",
							name = "风暴藤",
							desc = "在地图上显示风暴藤采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[52] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[52] = not Nx.db.profile.Guide.ShowHerbs[52]								
							end,							
						},												
						heartblossom = {						
							order = 53,
							type = "toggle",
							width = "full",
							name = "心灵之花",
							desc = "在地图上显示心灵之花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[53] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[53] = not Nx.db.profile.Guide.ShowHerbs[53]								
							end,							
						},												
						whiptail = {						
							order = 54,
							type = "toggle",
							width = "full",
							name = "鞭尾草",
							desc = "在地图上显示鞭尾草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[54] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[54] = not Nx.db.profile.Guide.ShowHerbs[54]								
							end,							
						},												
						twilightjas = {						
							order = 55,
							type = "toggle",
							width = "full",
							name = "暮光茉莉",
							desc = "在地图上显示暮光茉莉采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[55] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[55] = not Nx.db.profile.Guide.ShowHerbs[55]								
							end,							
						},												
						foolscap = {						
							order = 56,
							type = "toggle",
							width = "full",
							name = "愚人菇",
							desc = "在地图上显示愚人菇采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[56] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[56] = not Nx.db.profile.Guide.ShowHerbs[56]								
							end,							
						},												
						goldenlotus = {						
							order = 57,
							type = "toggle",
							width = "full",
							name = "黄金莲",
							desc = "在地图上显示黄金莲采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[57] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[57] = not Nx.db.profile.Guide.ShowHerbs[57]								
							end,							
						},												
						greentea = {						
							order = 58,
							type = "toggle",
							width = "full",
							name = "绿茶叶", --差点敲成绿茶婊
							desc = "在地图上显示绿茶叶采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[58] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[58] = not Nx.db.profile.Guide.ShowHerbs[58]								
							end,							
						},												
						rainpoppy = {						
							order = 59,
							type = "toggle",
							width = "full",
							name = "雨粟花",
							desc = "在地图上显示雨粟花采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[59] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[59] = not Nx.db.profile.Guide.ShowHerbs[59]								
							end,							
						},												
						shatouched = {						
							order = 60,
							type = "toggle",
							width = "full",
							name = "染煞草药",
							desc = "在地图上显示染煞草药采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[60] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[60] = not Nx.db.profile.Guide.ShowHerbs[60]								
							end,							
						},												
						silkweed = {						
							order = 61,
							type = "toggle",
							width = "full",
							name = "柔丝草",
							desc = "在地图上显示柔丝草采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[61] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[61] = not Nx.db.profile.Guide.ShowHerbs[61]								
							end,							
						},												
						snowlily = {						
							order = 62,
							type = "toggle",
							width = "full",
							name = "雪百合",
							desc = "在地图上显示雪百合采集点",
							get = function()
								return Nx.db.profile.Guide.ShowHerbs[62] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowHerbs[62] = not Nx.db.profile.Guide.ShowHerbs[62]								
							end,							
						},												
					},					
				},
				MinesDisp = {
					type = "group",
					name = "矿石采集点",
					order = 3,
					args = {
						adamantite = {						
							order = 1,
							type = "toggle",
							width = "full",
							name = "精金矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[1] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[1] = not Nx.db.profile.Guide.ShowMines[1]								
							end,							
						},
						richadamantite = {						
							order = 2,
							type = "toggle",
							width = "full",
							name = "富精金矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[15] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[15] = not Nx.db.profile.Guide.ShowMines[15]								
							end,							
						},						
						gemvein = {						
							order = 3,
							type = "toggle",
							width = "full",
							name = "上古宝石矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[2] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[2] = not Nx.db.profile.Guide.ShowMines[2]								
							end,							
						},		
						copper = {						
							order = 4,
							type = "toggle",
							width = "full",
							name = "铜矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[3] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[3] = not Nx.db.profile.Guide.ShowMines[3]								
							end,							
						},
						darkiron = {						
							order = 5,
							type = "toggle",
							width = "full",
							name = "黑铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[4] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[4] = not Nx.db.profile.Guide.ShowMines[4]								
							end,							
						},
						feliron = {						
							order = 6,
							type = "toggle",
							width = "full",
							name = "魔铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[5] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[5] = not Nx.db.profile.Guide.ShowMines[5]
							end,							
						},						
						gold = {						
							order = 7,
							type = "toggle",
							width = "full",
							name = "金矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[6] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[6] = not Nx.db.profile.Guide.ShowMines[6]								
							end,							
						},						
						incendicite = {						
							order = 8,
							type = "toggle",
							width = "full",
							name = "火岩矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[7] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[7] = not Nx.db.profile.Guide.ShowMines[7]								
							end,							
						},						
						indurium = {						
							order = 9,
							type = "toggle",
							width = "full",
							name = "精铁矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[8] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[8] = not Nx.db.profile.Guide.ShowMines[8]								
							end,							
						},						
						iron = {						
							order = 10,
							type = "toggle",
							width = "full",
							name = "铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[9] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[9] = not Nx.db.profile.Guide.ShowMines[9]								
							end,							
						},						
						korium = {						
							order = 11,
							type = "toggle",
							width = "full",
							name = "氪金矿", --叫Khorium不上Korium啊
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[10] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[10] = not Nx.db.profile.Guide.ShowMines[10]								
							end,							
						},						
						smallobsi = {						
							order = 12,
							type = "toggle",
							width = "full",
							name = "小型黑曜石碎块",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[18] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[18] = not Nx.db.profile.Guide.ShowMines[18]								
							end,							
						},						
						largeobs = {						
							order = 13,
							type = "toggle",
							width = "full",
							name = "大型黑曜石碎块",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[11] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[11] = not Nx.db.profile.Guide.ShowMines[11]								
							end,							
						},						
						bloodstone = {						
							order = 14,
							type = "toggle",
							width = "full",
							name = "血石矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[12] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[12] = not Nx.db.profile.Guide.ShowMines[12]								
							end,							
						},						
						mithril = {						
							order = 15,
							type = "toggle",
							width = "full",
							name = "秘银矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[13] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[13] = not Nx.db.profile.Guide.ShowMines[13]								
							end,							
						},						
						nethercite = {						
							order = 16,
							type = "toggle",
							width = "full",
							name = "虚空矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[14] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[14] = not Nx.db.profile.Guide.ShowMines[14]								
							end,							
						},						
						smallthor = {						
							order = 17,
							type = "toggle",
							width = "full",
							name = "瑟银矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[19] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[19] = not Nx.db.profile.Guide.ShowMines[19]								
							end,							
						},						
						richthor = {						
							order = 18,
							type = "toggle",
							width = "full",
							name = "富瑟银矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[16] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[16] = not Nx.db.profile.Guide.ShowMines[16]								
							end,							
						},						
						silver = {						
							order = 19,
							type = "toggle",
							width = "full",
							name = "银矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[17] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[17] = not Nx.db.profile.Guide.ShowMines[17]								
							end,							
						},						
						tin = {						
							order = 20,
							type = "toggle",
							width = "full",
							name = "锡矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[20] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[20] = not Nx.db.profile.Guide.ShowMines[20]								
							end,							
						},						
						truesilver = {						
							order = 21,
							type = "toggle",
							width = "full",
							name = "真银矿", --真银剑!
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[21] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[21] = not Nx.db.profile.Guide.ShowMines[21]								
							end,							
						},						
						cobalt = {						
							order = 22,
							type = "toggle",
							width = "full",
							name = "钴矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[22] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[22] = not Nx.db.profile.Guide.ShowMines[22]								
							end,							
						},												
						richcobalt = {						
							order = 23,
							type = "toggle",
							width = "full",
							name = "富钴矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[23] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[23] = not Nx.db.profile.Guide.ShowMines[23]								
							end,							
						},												
						saronite = {						
							order = 24,
							type = "toggle",
							width = "full",
							name = "萨隆邪铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[24] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[24] = not Nx.db.profile.Guide.ShowMines[24]								
							end,							
						},												
						richsaron = {						
							order = 25,
							type = "toggle",
							width = "full",
							name = "富萨隆邪铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[25] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[25] = not Nx.db.profile.Guide.ShowMines[25]								
							end,							
						},												
						titan = {						
							order = 26,
							type = "toggle",
							width = "full",
							name = "泰坦神铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[26] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[26] = not Nx.db.profile.Guide.ShowMines[26]								
							end,							
						},												
						obsid = {						
							order = 27,
							type = "toggle",
							width = "full",
							name = "黑曜石碎块",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[27] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[27] = not Nx.db.profile.Guide.ShowMines[27]								
							end,							
						},												
						richobs = {						
							order = 28,
							type = "toggle",
							width = "full",
							name = "巨型黑曜石石板",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[28] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[28] = not Nx.db.profile.Guide.ShowMines[28]								
							end,							
						},
						elemen = {						
							order = 29,
							type = "toggle",
							width = "full",
							name = "源质矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[29] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[29] = not Nx.db.profile.Guide.ShowMines[29]								
							end,							
						},						
						richelem = {						
							order = 30,
							type = "toggle",
							width = "full",
							name = "富源质矿脉",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[30] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[30] = not Nx.db.profile.Guide.ShowMines[30]								
							end,							
						},						
						pyrite = {						
							order = 31,
							type = "toggle",
							width = "full",
							name = "燃铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[31] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[31] = not Nx.db.profile.Guide.ShowMines[31]								
							end,							
						},						
						richpyr = {						
							order = 32,
							type = "toggle",
							width = "full",
							name = "富燃铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[32] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[32] = not Nx.db.profile.Guide.ShowMines[32]								
							end,							
						},						
						ghost = {						
							order = 33,
							type = "toggle",
							width = "full",
							name = "幽冥铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[33] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[33] = not Nx.db.profile.Guide.ShowMines[33]								
							end,							
						},						
						richghost = {						
							order = 34,
							type = "toggle",
							width = "full",
							name = "富幽冥铁矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[34] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[34] = not Nx.db.profile.Guide.ShowMines[34]								
							end,							
						},						
						kypar = {						
							order = 35,
							type = "toggle",
							width = "full",
							name = "凯帕琥珀",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[35] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[35] = not Nx.db.profile.Guide.ShowMines[35]								
							end,							
						},						
						richkyp = {						
							order = 36,
							type = "toggle",
							width = "full",
							name = "富凯帕琥珀",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[36] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[36] = not Nx.db.profile.Guide.ShowMines[36]								
							end,							
						},						
						trill = {						
							order = 37,
							type = "toggle",
							width = "full",
							name = "延极矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[37] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[37] = not Nx.db.profile.Guide.ShowMines[37]								
							end,							
						},						
						richtrill = {						
							order = 38,
							type = "toggle",
							width = "full",
							name = "富延极矿",
							desc = "在地图上显示此种矿石采集点",
							get = function()
								return Nx.db.profile.Guide.ShowMines[38] 
							end,
							set = function()
								Nx.db.profile.Guide.ShowMines[38] = not Nx.db.profile.Guide.ShowMines[38]								
							end,							
						},						
					},					
				},				
			},
		}
	end
	return guidegather
end

local menuoptions

local function menuConfig()
	if not menuoptions then
		menuoptions = {		
			type = "group",
			name = "Menu Options",
			args = {
				menuCenterX = {
					order = 1,
					type = "toggle",
					width = "full",
					name = "菜单弹出时以鼠标位置水平居中",
					desc = "启用时, Carbonite 菜单弹出时将以当前鼠标所在位置水平居中",
					get = function()
						return Nx.db.profile.Menu.CenterH 
					end,
					set = function()
						Nx.db.profile.Menu.CenterH = not Nx.db.profile.Menu.CenterH
					end,				
				},	
				menuCenterY = {
					order = 2,
					type = "toggle",
					width = "full",
					name = "菜单弹出时以鼠标位置垂直居中",
					desc = "启用时, Carbonite 菜单弹出时将以当前鼠标所在位置垂直居中",
					get = function()
						return Nx.db.profile.Menu.CenterV 
					end,
					set = function()
						Nx.db.profile.Menu.CenterV = not Nx.db.profile.Menu.CenterV
					end,				
				},						
			},
		}
	end
	return menuoptions
end

local commoptions
local function commConfig()
	if not commoptions then
		commoptions = {
			type = "group",
			name = "隐私选项",
			args = {
				commLTF = {
					order = 1,
					type = "toggle",
					width = "full",
					name = "发送位置&升级提示至好友",
					desc = "启用时, Carbonite 将在好友里发送你的位置和升级提示给其他Carbonite用户",
					get = function()
						return Nx.db.profile.Comm.SendToFriends 
					end,
					set = function()
						Nx.db.profile.Comm.SendToFriends = not Nx.db.profile.Comm.SendToFriends
					end,				
				},	
				commLTG = {
					order = 2,
					type = "toggle",
					width = "full",
					name = "发送位置&升级提示至公会",
					desc = "启用时, Carbonite 将在公会中发送你的位置和升级提示给其他Carbonite用户",
					get = function()
						return Nx.db.profile.Comm.SendToGuild 
					end,
					set = function()
						Nx.db.profile.Comm.SendToGuild = not Nx.db.profile.Comm.SendToGuild
					end,				
				},		
				commLTZ = {
					order = 3,
					type = "toggle",
					width = "full",
					name = "发送位置&升级提示至当前地区",
					desc = "启用时, Carbonite 将在当前地区发送你的位置和升级提示给其他Carbonite用户",
					get = function()
						return Nx.db.profile.Comm.SendToZone 
					end,
					set = function()
						Nx.db.profile.Comm.SendToZone = not Nx.db.profile.Comm.SendToZone
					end,				
				},		
				commShowLevel = {
					order = 4,
					type = "toggle",
					width = "full",
					name = "显示升级提示",
					desc = "启用时, Carbonite 将在聊天窗口显示其他Carbonite用户的升级提示",
					get = function()
						return Nx.db.profile.Comm.LvlUpShow
					end,
					set = function()
						Nx.db.profile.Comm.LvlUpShow = not Nx.db.profile.Comm.LvlUpShow
					end,				
				},		
				commDisG = {
					order = 5,
					type = "toggle",
					width = "full",
					name = "启用全局频道 (用来发布/检查更新)",
					desc = "启用时, Carbonite 将自动检查并告知你可用更新",
					get = function()
						return Nx.db.profile.Comm.Global 
					end,
					set = function()
						Nx.db.profile.Comm.Global = not Nx.db.profile.Comm.Global
					end,				
				},		
				commDisZ = {
					order = 6,
					type = "toggle",
					width = "full",
					name = "启用地区频道 (用来定位本地区内其他Carbonite用户)",
					desc = "启用时, Carbonite 将与其他Carbonite用户交换位置信息",
					get = function()
						return Nx.db.profile.Comm.Zone 
					end,
					set = function()
						Nx.db.profile.Comm.Zone = not Nx.db.profile.Comm.Zone
					end,				
				},		
				
			},			
		}
	end
	return commoptions
end

local skinoptions
local function skinConfig()
	if not skinoptions then
		skinoptions = {
			type = "group",
			name = "Skin Options",
			args = {		
				SkinSelect = {
					order = 1,
					type	= "select",
					name	= "当前皮肤",
					desc	= "为Carbonite设置当前皮肤",
					get	= function()
						local vals = Nx.Opts:CalcChoices("Skins")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.Skin.Name) then
							 return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("Skins")
						Nx.db.profile.Skin.Name = vals[name]	
						if vals[name] == "Default" then
							Nx.db.profile.Skin.Name = ""
						end
						Nx.Skin:Set(Nx.db.profile.Skin.Name)
					end,
					values	= function()
						return Nx.Opts:CalcChoices("Skins")
					end,					
				},
				skinBord = {
					order = 2,
					type = "color",
					width = "full",
					name = "窗口边框颜色",
					hasAlpha = true,
					get = function()
						local arr = { Nx.Split("|",Nx.db.profile.Skin.WinBdColor) }
						local r = arr[1]
						local g = arr[2]
						local b = arr[3]
						local a = arr[4]
						return r,g,b,a
					end,
					set = function(_,r,g,b,a)
						Nx.db.profile.Skin.WinBdColor = r .. "|" .. g .. "|" .. b .. "|" .. a
						Nx.Skin:Update()
					end,						
				},				
				skinFixBG = {
					order = 3,
					type = "color",
					width = "full",
					name = "固定大小的窗口的背景色",
					hasAlpha = true,
					get = function()
						local arr = { Nx.Split("|",Nx.db.profile.Skin.WinFixedBgColor) }
						local r = arr[1]
						local g = arr[2]
						local b = arr[3]
						local a = arr[4]
						return r,g,b,a
					end,
					set = function(_,r,g,b,a)
						Nx.db.profile.Skin.WinFixedBgColor = r .. "|" .. g .. "|" .. b .. "|" .. a
						Nx.Skin:Update()
					end,						
				},		
				skinSizeBG = {
					order = 4,
					type = "color",
					width = "full",
					name = "可改变大小的窗口的背景色",
					hasAlpha = true,
					get = function()
						local arr = { Nx.Split("|",Nx.db.profile.Skin.WinSizedBgColor) }
						local r = arr[1]
						local g = arr[2]
						local b = arr[3]
						local a = arr[4]
						return r,g,b,a
					end,
					set = function(_,r,g,b,a)
						Nx.db.profile.Skin.WinSizedBgColor = r .. "|" .. g .. "|" .. b .. "|" .. a
						Nx.Skin:Update()
					end,						
				},		
				
			},
		}
	end
	return skinoptions
end

local trackoptions

local function trackConfig()
	if not trackoptions then
		trackoptions = {		
			type = "group",
			name = "Tracking Options",
			args = {
				hideHUD = {
					order = 1,
					type = "toggle",
					width = "full",
					name = "隐藏追踪窗口",
					desc = "启用时, Carbonite 将隐藏追踪窗口",
					get = function()
						return Nx.db.profile.Track.Hide
					end,
					set = function()
						Nx.db.profile.Track.Hide = not Nx.db.profile.Track.Hide
					end,				
				},		
				hideHUDBG = {
					order = 2,
					type = "toggle",
					width = "full",
					name = "战场中隐藏追踪窗口",
					desc = "启用时, Carbonite 将在战场中隐藏追踪窗口",
					get = function()
						return Nx.db.profile.Track.HideInBG
					end,
					set = function()
						Nx.db.profile.Track.HideInBG = not Nx.db.profile.Track.HideInBG
					end,				
				},		
				hideLock = {
					order = 3,
					type = "toggle",
					width = "full",
					name = "锁定追踪窗口位置",
					desc = "启用时, Carbonite 将锁定追踪窗口的位置",
					get = function()
						return Nx.db.profile.Track.Lock
					end,
					set = function()
						Nx.db.profile.Track.Lock = not Nx.db.profile.Track.Lock
						Nx.HUD:UpdateOptions()
					end,				
				},		
				TrackArrow = {
					order = 4,
					type	= "select",
					name	= "追踪窗口箭头样式",
					desc	= "设置追踪窗口箭头的样式",
					get	= function()
						local vals = Nx.Opts:CalcChoices("HUDAGfx")
						for a,b in pairs(vals) do
						  if (b == Nx.db.profile.Track.AGfx) then
							 return a
						  end
						end
						return ""
					end,
					set	= function(info, name)
						local vals = Nx.Opts:CalcChoices("HUDAGfx")
						Nx.db.profile.Track.AGfx = vals[name]	
						Nx.HUD:UpdateOptions()
					end,
					values	= function()
						return Nx.Opts:CalcChoices("HUDAGfx")
					end,					
				},
				spacer = {
					order = 5,
					type = "description",
					width = "double",
					name = "",
				},
				ArrowSize = {
					order = 6,
					type = "range",							
					name = "箭头大小",						
					desc = "设置追踪窗口中箭头大小",
					min = 8,
					max = 100,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Track.ASize
					end,
					set = function(info,value)
						Nx.db.profile.Track.ASize = value								
						Nx.HUD:UpdateOptions()
					end,				
				},								
				AXO = {
					order = 7,
					type = "range",							
					name = "箭头X轴偏移量",						
					desc = "设置追踪窗口中箭头X轴偏移量",
					min = -100,
					max = 100,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Track.AXO
					end,
					set = function(info,value)
						Nx.db.profile.Track.AXO = value								
						Nx.HUD:UpdateOptions()
					end,				
				},								
				AYO = {
					order = 8,
					type = "range",							
					name = "箭头Y轴偏移量",						
					desc = "设置追踪窗口中箭头Y轴偏移量",
					min = -100,
					max = 100,
					step = 1,
					bigStep = 1,
					get = function()
						return Nx.db.profile.Track.AYO
					end,
					set = function(info,value)
						Nx.db.profile.Track.AYO = value								
						Nx.HUD:UpdateOptions()
					end,				
				},								
				showText = {
					order = 9,
					type = "toggle",
					width = "full",
					name = "显示方向文字",
					desc = "启用时, 在追踪窗口中显示额外的文字",
					get = function()
						return Nx.db.profile.Track.ShowDir
					end,
					set = function()
						Nx.db.profile.Track.ShowDir = not Nx.db.profile.Track.ShowDir
						Nx.HUD:UpdateOptions()
					end,				
				},						
				addTbut = {
					order = 10,
					type = "toggle",
					width = "full",
					name = "启用目标按钮",
					desc = "启用时, 将在追踪窗口中添加一个目标按钮",
					get = function()
						return Nx.db.profile.Track.TBut
					end,
					set = function()
						Nx.db.profile.Track.TBut = not Nx.db.profile.Track.TBut
						Nx.HUD:UpdateOptions()
					end,				
				},										
				Tbutcol = {
					order = 11,
					type = "color",
					width = "full",
					name = "目标按钮的颜色",
					hasAlpha = true,
					get = function()
						local arr = { Nx.Split("|",Nx.db.profile.Track.TButColor) }
						local r = arr[1]
						local g = arr[2]
						local b = arr[3]
						local a = arr[4]
						return r,g,b,a
					end,
					set = function(_,r,g,b,a)
						Nx.db.profile.Track.TButColor = r .. "|" .. g .. "|" .. b .. "|" .. a
						Nx.HUD:UpdateOptions()
					end,						
				},						
				Tbutcomcol = {
					order = 12,
					type = "color",
					width = "full",
					name = "战斗中目标按钮的颜色",
					hasAlpha = true,
					get = function()
						local arr = { Nx.Split("|",Nx.db.profile.Track.TButCombatColor) }
						local r = arr[1]
						local g = arr[2]
						local b = arr[3]
						local a = arr[4]
						return r,g,b,a
					end,
					set = function(_,r,g,b,a)
						Nx.db.profile.Track.TButCombatColor = r .. "|" .. g .. "|" .. b .. "|" .. a
						Nx.Skin:Update()
					end,						
				},						
				addsound = {
					order = 13,
					type = "toggle",
					width = "full",
					name = "启用到达目的地音效",
					desc = "启用时, 在你到达目的地之后将自动播放音效",
					get = function()
						return Nx.db.profile.Track.TSoundOn
					end,
					set = function()
						Nx.db.profile.Track.TSoundOn = not Nx.db.profile.Track.TSoundOn
						Nx.HUD:UpdateOptions()
					end,				
				},					
				spacer2 = {
					order = 14,
					type = "description",
					width = "full",
					name = " ",
				},
				autopals = {
					order = 15,
					type = "toggle",
					width = "full",
					name = "战场中自动追踪好友",
					desc = "启用时, 在战场中将自动追踪你的好友",
					get = function()
						return Nx.db.profile.Track.ATBGPal
					end,
					set = function()
						Nx.db.profile.Track.ATBGPal = not Nx.db.profile.Track.ATBGPal						
					end,				
				},					
				autotaxi = {
					order = 16,
					type = "toggle",
					width = "full",
					name = "自动追踪飞行目的地",
					desc = "启用时, 将自动追踪你的飞行目的地",
					get = function()
						return Nx.db.profile.Track.ATTaxi
					end,
					set = function()
						Nx.db.profile.Track.ATtaxi = not Nx.db.profile.Track.ATTaxi
						Nx.HUD:UpdateOptions()
					end,				
				},					
				autocorpse = {
					order = 17,
					type = "toggle",
					width = "full",
					name = "自动追踪尸体",
					desc = "启用时, 死后将自动追踪你的尸体",
					get = function()
						return Nx.db.profile.Track.ATCorpse
					end,
					set = function()
						Nx.db.profile.Track.ATCorpse = not Nx.db.profile.Track.ATCorpse
						Nx.HUD:UpdateOptions()
					end,				
				},									
				spacer3 = {
					order = 18,
					type = "description",
					width = "full",
					name = " ",
				},				
				emutomtom = {
					order = 19,
					type = "toggle",
					width = "full",
					name = "启用TomTom模拟",
					desc = "启用时, 将开启对 tomtom 的模拟 (需要重载界面)",
					get = function()
						return Nx.db.profile.Track.EmuTomTom
					end,
					set = function()
						Nx.db.profile.Track.EmuTomTom = not Nx.db.profile.Track.EmuTomTom
						Nx.HUD:UpdateOptions()
					end,				
				},									
			},
		}
	end
	return trackoptions
end
function Nx:SetupConfig()
	AceConfig:RegisterOptionsTable("Carbonite", mainConfig)
	Nx.optionsFrame = AceConfigDialog:AddToBlizOptions("Carbonite", "Carbonite",nil,"main")
	Nx:AddToConfig("General",generalOptions(),"一般")
	Nx:AddToConfig("Battlegrounds", BGConfig(), "战场")
	Nx:AddToConfig("Fonts",fontConfig(),"字体")
	Nx:AddToConfig("Guide & Gather", guidegatherConfig(),"采集向导")
	Nx:AddToConfig("Maps",mapConfig(),"地图")
	Nx:AddToConfig("Menus",menuConfig(),"菜单")
	Nx:AddToConfig("Privacy",commConfig(),"隐私")
--	Nx:AddToConfig("Profiles",profilesConfig(),"Profiles")
	Nx:AddToConfig("Skin",skinConfig(),"皮肤")
	Nx:AddToConfig("Tracking HUD",trackConfig(),"追踪窗口")
end

function Nx:AddToConfig(name, optionsTable, displayName)
	modular_config[name] = optionsTable
	Nx.optionsFrame[name] = AceConfigDialog:AddToBlizOptions("Carbonite", displayName, "Carbonite", name)
end

local function giveProfiles()
	return LibStub("AceDBOptions-3.0"):GetOptionsTable(Nx.db)
end

Nx.OptsDataSounds = {
	"Interface\\AddOns\\Carbonite\\Snd\\QuestComplete.ogg",
	"Sound\\Creature\\Peon\\PeonBuildingComplete1.wav",
	"Sound\\Character\\Scourge\\ScourgeVocalMale\\UndeadMaleCongratulations02.wav",
	"Sound\\Character\\Human\\HumanVocalFemale\\HumanFemaleCongratulations01.wav",
	"Sound\\Character\\Dwarf\\DwarfVocalMale\\DwarfMaleCongratulations04.wav",
	"Sound\\Character\\Gnome\\GnomeVocalMale\\GnomeMaleCongratulations03.wav",
	"Sound\\Creature\\Tauren\\TaurenYes3.wav",
	"Sound\\Creature\\UndeadMaleWarriorNPC\\UndeadMaleWarriorNPCGreeting01.wav",
}

-------------------------------------------------------------------------------

--------
-- Init options data. Called before UI init

function Nx.Opts:Init()

	self.ChoicesAnchor = {
		"TopLeft", "Top", "TopRight",
		"Left", "Center", "Right",
		"BottomLeft", "Bottom", "BottomRight",
	}
	self.ChoicesAnchor0 = {
		"None",
		"TopLeft", "Top", "TopRight",
		"Left", "Center", "Right",
		"BottomLeft", "Bottom", "BottomRight",
	}
	self.Skins = {		
		"Blackout","Blackout Blues","Dialog Blue",
		"Dialog Gold","Simple Blue","Stone","Tool Blue",
	}
	self.ChoicesCorner = { "TopLeft", "TopRight", "BottomLeft", "BottomRight", }

	self.ChoicesQArea = {
		"Solid", "SolidTexture", "HGrad",
	}
	self.ChoicesQAreaTex = {
		["SolidTexture"] = "Interface\\Buttons\\White8x8",
		["HGrad"] = "Interface\\AddOns\\Carbonite\\Gfx\\Map\\AreaGrad",
	}

	self:Reset (true)
	self:UpdateCom()

	OptsInit = Nx:ScheduleTimer(self.InitTimer, .5, self)

--	Nx.prt ("cvar %s", GetCVar ("farclip") or "nil")

--	RegisterCVar ("dog", "hi")
--	Nx.prt ("dog %s", GetCVar ("dog") or "nil")
end

--------
-- Init timer

function Nx.Opts:InitTimer()

--	Nx.prt ("cvar %s", GetCVar ("farclip") or "nil")

--	Nx.prt ("dog2 %s", GetCVar ("dog") or "nil")

	self:NXCmdGryphonsUpdate()
	self:NXCmdCamForceMaxDist()

	OptsQO = Nx:ScheduleTimer(self.QuickOptsTimer,2,self)
end

--------
-- Show quick options timer

function Nx.Opts:QuickOptsTimer()
	
	local i = Nx.db.profile.Version.QuickVer or 0

	local ver = 5

	Nx.db.profile.Version.QuickVer = ver

	if i < ver then

		local function func()			
			Nx.db.profile.MiniMap.Own = true
			Nx.db.profile.MiniMap.ButOwn = true
			Nx.db.profile.MiniMap.ShowOldNameplate = false
			ReloadUI()
		end

		local s = "是否将小地图整合到Carbonite地图？\n\n这将会生成一个合并地图，并将小地图周围的按钮整合进Carbonite按钮窗口。你也可以在Carbonite的地图设置中找到这个功能。"

		Nx:ShowMessage (s, "是", func, "否")
	end
end

--------
-- Reset options (can be called before Init)

function Nx.Opts:Reset (onlyNew)
	self.COpts = Nx.CurCharacter["Opts"]
	self.Opts = Nx.db.profile
	
	if not onlyNew then
		Nx.prt ("重置全局选项")
		Nx.db:ResetDB("Default")
	end
end

--------
-- Open options

function Nx.Opts:Open (pageName)
	InterfaceOptionsFrame_OpenToCategory("Carbonite")
	InterfaceOptionsFrame_OpenToCategory("Carbonite")
end

--------
-- Open options

function Nx.Opts:Create()

	-- Create Window

	local win = Nx.Window:Create ("NxOpts", nil, nil, nil, 1)
	self.Win = win
	local frm = win.Frm

	win:CreateButtons (true, true)
	win:InitLayoutData (nil, -.25, -.1, -.5, -.7)

	tinsert (UISpecialFrames, frm:GetName())

	frm:SetToplevel (true)

	win:SetTitle (Nx.TXTBLUE.."CARBONITE " .. Nx.VERSION .. "|cffffffff Options")

	-- Page list

	local listW = 115

	local list = Nx.List:Create (false, 0, 0, 1, 1, frm)
	self.PageList = list

	list:SetUser (self, self.OnPageListEvent)
	win:Attach (list.Frm, 0, listW, 0, 1)

	list:SetLineHeight (8)

	list:ColumnAdd ("Page", 1, listW)

	for k, t in ipairs (Nx.OptsData) do

		list:ItemAdd (k)
		list:ItemSet (1, t.N)
	end

	self.PageSel = 1

	-- Item list

	Nx.List:SetCreateFont ("Font.Medium", 24)

	local list = Nx.List:Create (false, 0, 0, 1, 1, win.Frm)
	self.List = list

	list:SetUser (self, self.OnListEvent)

	list:SetLineHeight (12, 3)

	list:ColumnAdd ("", 1, 40)
	list:ColumnAdd ("", 2, 900)

	win:Attach (list.Frm, listW, 1, 0, 1)

	--

	self:Update()
end

--------

function Nx.Opts:NXCmdFavCartImport()
	Nx.Notes:CartImportNotes()
end

function Nx.Opts:NXCmdFontChange()
	Nx.Font:Update()
end

function Nx.Opts:NXCmdCamForceMaxDist()

--	Nx.prt ("Cam %s", GetCVar ("cameraDistanceMaxFactor"))

	if Nx.db.profile.General.CameraForceMaxDist then
		SetCVar ("cameraDistanceMaxFactor", 3.4)
	end
end

function Nx.Opts:NXCmdGryphonsUpdate()
	if Nx.db.profile.General.GryphonsHide then
		MainMenuBarLeftEndCap:Hide()
		MainMenuBarRightEndCap:Hide()
	else
		MainMenuBarLeftEndCap:Show()
		MainMenuBarRightEndCap:Show()
	end
end

function Nx.Opts:NXCmdDeleteHerb()

	local function func()
		Nx:GatherDeleteHerb()
	end
	Nx:ShowMessage ("删除草点信息？", "删除", func, "取消")
end

function Nx.Opts:NXCmdDeleteMine()

	local function func()
		Nx:GatherDeleteMine()
	end
	Nx:ShowMessage ("删除矿点信息？", "删除", func, "取消")
end

function Nx.Opts:NXCmdDeleteMisc()

	local function func()
		Nx:GatherDeleteMisc()
	end
	Nx:ShowMessage ("删除杂项信息？", "删除", func, "取消")
end

function Nx.Opts:NXCmdImportCarbHerb()

	local function func()
		Nx:GatherImportCarbHerb()
	end
	Nx:ShowMessage ("导入草点？", "导入", func, "取消")
end

function Nx.Opts:NXCmdImportCarbMine()

	local function func()
		Nx:GatherImportCarbMine()
	end
	Nx:ShowMessage ("导入矿点？", "导入", func, "取消")
end

function Nx.Opts:NXCmdImportCarbMisc()

	local function func()
		Nx:GatherImportCarbMisc()
	end
	Nx:ShowMessage ("导入其他信息？", "导入", func, "取消")
end

--[[
function Nx.Opts:NXCmdImportCartHerb()

	local function func()
		Nx:GatherImportCartHerb()
	end
	Nx:ShowMessage ("Import Herbs?", "导入", func, "取消")
end

function Nx.Opts:NXCmdImportCartMine()

	local function func()
		Nx:GatherImportCartMine()
	end
	Nx:ShowMessage ("Import Mining?", "导入", func, "取消")
end
--]]

function Nx.Opts:NXCmdInfoWinUpdate()
	if Nx.Info then
		Nx.Info:OptionsUpdate()
	end
end

function Nx.Opts:NXCmdMMOwnChange (item, var)
	Nx.db.profile.MiniMap.ShowOldNameplate = not var		-- Nameplate is opposite of integration
	Nx.db.profile.MiniMap.ButOwn = var
	self:Update()
	self:NXCmdReload()
end

function Nx.Opts:NXCmdMMButUpdate()
	Nx.Map:MinimapButtonShowUpdate()
	Nx.Map.Dock:UpdateOptions()
end

-- Generic minimap change

function Nx.Opts:NXCmdMMChange()
	local map = Nx.Map:GetMap (1)
	map:MinimapNodeGlowInit (true)
end

function Nx.Opts:NXCmdMapToolBarUpdate()
	local map = Nx.Map:GetMap (1)
	map:UpdateToolBar()
end

--function Nx.Opts:NXCmdWatchFont()
--	Nx.Quest.Watch:SetFont()
--end

function Nx.Opts:NXCmdQWFadeAll (item, var)
	Nx.Quest.Watch:WinUpdateFade (var and Nx.Quest.Watch.Win:GetFade() or 1, true)
end

function Nx.Opts:NXCmdQWHideRaid()
	Nx.Quest.Watch.Win.Frm:Show()
end

function Nx.Opts:NXCmdImportCharSettings()

	local function func (self, name)

		local function func()

--			Nx.prt ("OK %s", name)

			if Nx:CopyCharacterData (name, UnitName ("player")) then
				ReloadUI()
			end
		end

		Nx:ShowMessage (format ("导入 %s 的数据并重载界面吗?", name), "导入", func, "取消")
	end

	local t = {}

	for rc in pairs (Nx.db.global.Characters) do
		tinsert (t, rc)
	end

	sort (t)

	Nx.DropDown:Start (self, func)
	Nx.DropDown:AddT (t, 1)
	Nx.DropDown:Show (self.List.Frm)
end

function Nx.Opts:NXCmdDeleteCharSettings()

	local function func (self, name)

		local function func()

--			Nx.prt ("OK %s", name)

			Nx:DeleteCharacterData (name)
		end

		Nx:ShowMessage (format ("删除 %s 的数据吗?", name), "删除", func, "取消")
	end

	local rcName = Nx:GetRealmCharName()

	local t = {}

	for rc in pairs (Nx.db.global.Characters) do
		if rc ~= rcName then
			tinsert (t, rc)
		end
	end

	sort (t)

	Nx.DropDown:Start (self, func)
	Nx.DropDown:AddT (t, 1)
	Nx.DropDown:Show (self.List.Frm)
end

function Nx.Opts:NXCmdResetOpts()

	local function func()
		local self = Nx.Opts
		self:Reset()
		self:Update()
		Nx.Skin:Set()
		Nx.Font:Update()
		Nx.Quest:OptsReset()
		Nx.Quest:CalcWatchColors()
		self:NXCmdHUDChange()
		self:NXCmdGryphonsUpdate()
		self:NXCmdInfoWinUpdate()
		self:NXCmdUIChange()
	end

	Nx:ShowMessage ("重置选项？", "重置", func, "取消")
end

function Nx.Opts:NXCmdResetWinLayouts()

	local function func()
		Nx.Window:ResetLayouts()
	end

	Nx:ShowMessage ("重置窗体布局？", "重置", func, "取消")
end

function Nx.Opts:NXCmdResetWatchWinLayout()
	Nx.Quest.Watch.Win:ResetLayout()
end

function Nx.Opts:NXCmdReload()

	local function func()
		ReloadUI()
	end

	Nx:ShowMessage ("重载界面？", "重载", func, "取消")
end

function Nx.Opts:NXCmdHUDChange()
	Nx.HUD:UpdateOptions()
end

--------
-- Do simple call anytime UI changes

function Nx.Opts:NXCmdUIChange()
	Nx:prtSetChatFrame()
end

--------

function Nx.Opts:OnSetSize (w, h)

	Nx.Opts.FStr:SetWidth (w)
end

function Nx.Opts:OnPageListEvent (eventName, sel, val2)

	if eventName == "select" or eventName == "back" then
		self.PageSel = sel
		self:Update()
	end
end

function Nx.Opts:OnListEvent (eventName, sel, val2)

	local page = Nx.OptsData[self.PageSel]
	local item = page[sel]

	if eventName == "select" or eventName == "back" then

		if item then

			if type (item) == "table" then
				if item.F then
					local var = self:GetVar (item.V)
					Nx.Opts[item.F](self, item, var)
				end

				if item.V then
					self:EditItem (item)
				end
			end
		end

	elseif eventName == "button" then

--		Nx.prt ("but %s", val2 and "T" or "F")

		if item then
			if type (item) == "table" then
				if item.V then
					self:SetVar (item.V, val2)
				end
				if item.VF then
					local var = self:GetVar (item.V)
					Nx.Opts[item.VF](self, item, var)
				end
			end
		end

	elseif eventName == "color" then

		if item then
			if type (item) == "table" then
				if item.VF then
					Nx.Opts[item.VF](self, item)
				end
			end
		end
	end

	self:Update()
end

--------
-- Update options

function Nx.Opts:Update()

	local opts = self.Opts
	local list = self.List

	if not list then
		return
	end

	list:Empty()

	local page = Nx.OptsData[self.PageSel]

	for k, item in ipairs (page) do

		list:ItemAdd (k)

		if type (item) == "table" then

			if item.N then

				local col = "|cff9f9f9f"

				if item.F then				-- Function?
					col = "|cff8fdf8f"
				elseif item.V then
					col = "|cffdfdfdf"
				end

				local istr = format ("%s%s", col, item.N)

				if item.V then

					local typ, pressed, tx = self:ParseVar (item.V)
					if typ == "B" then

						if pressed ~= nil then
							local tip
							list:ItemSetButton ("Opts", pressed, tx, tip)
						end

					elseif typ == "C" then

						list:ItemSetColorButton (opts, item.V, true)

					elseif typ == "RGB" then

						list:ItemSetColorButton (opts, item.V, false)

					elseif typ == "CH" then	-- Choice

						local i = self:GetVar (item.V)
						istr = format ("%s  |cffffff80%s", istr, i)

					elseif typ == "F" then

						local i = self:GetVar (item.V)
						istr = format ("%s  |cffffff80%s", istr, i)

					elseif typ == "I" then

						local i = self:GetVar (item.V)
						istr = format ("%s  |cffffff80%s", istr, i)

					elseif typ == "S" then

						local s = self:GetVar (item.V)
						istr = format ("%s  |cffffff80%s", istr, s)

					elseif typ == "Frm" then

--						list:ItemSetFrame ("Color")

					end
				end

				list:ItemSet (2, istr)
			end

		elseif type (item) == "string" then

			local col = "|cff9f9f9f"
			list:ItemSet (2, format ("%s%s", col, item))
		end
	end

	list:FullUpdate()

	self:UpdateCom()
end

function Nx.Opts:UpdateCom()

	local opts = self.Opts

	local mask = 0

	if Nx.db.profile.Comm.SendToFriends then
		mask = mask + 1
	end

	if Nx.db.profile.Comm.SendToGuild then
		mask = mask + 2
	end

	if Nx.db.profile.Comm.SendToZone then
		mask = mask + 4
	end

	Nx.Com:SetSendPalsMask (mask)
end

--------

function Nx.Opts:EditItem (item)

	local var = self:GetVar (item.V)
	local typ, r1 = self:ParseVar (item.V)

	if typ == "CH" then

		self.CurItem = item

		local data = self:CalcChoices (r1, "Get")
		if not data then
			Nx.prt ("EditItem error (%s)", r1)
		end
		Nx.DropDown:Start (self, self.EditCHAccept)
		for k, name in ipairs (data) do
			Nx.DropDown:Add (name, name == var)
		end
		Nx.DropDown:Show (self.List.Frm)
--[[
		local s = self:CalcChoices (r1, "Inc", var)
		self:SetVar (item.V, s)
		self:Update()

		if item.VF then
			local var = self:GetVar (item.V)
			self[item.VF](self, item, var)
		end
--]]
	elseif typ == "F" then
		Nx:ShowEditBox (item.N, var, item, self.EditFAccept)

	elseif typ == "I" then
		Nx:ShowEditBox (item.N, var, item, self.EditIAccept)

	elseif typ == "S" then
		Nx:ShowEditBox (item.N, var, item, self.EditSAccept)

	end
end

function Nx.Opts:EditCHAccept (name)

	local item = self.CurItem

	self:SetVar (item.V, name)
	self:Update()

	if item.VF then
		local var = self:GetVar (item.V)
		self[item.VF](self, item, var)
	end
end

function Nx.Opts.EditFAccept (str, item)

	local self = Nx.Opts

	local i = tonumber (str)
	if i then
		self:SetVar (item.V, i)
		self:Update()

		if item.VF then
			local var = self:GetVar (item.V)
			self[item.VF](self, item, var)
		end
	end
end

function Nx.Opts.EditIAccept (str, item)

	local self = Nx.Opts

	local i = tonumber (str)
	if i then
		self:SetVar (item.V, floor (i))
		self:Update()

		if item.VF then
			local var = self:GetVar (item.V)
			self[item.VF](self, item, var)
		end
	end
end

function Nx.Opts.EditSAccept (str, item)

	local self = Nx.Opts

	if str then
		self:SetVar (item.V, str)
		self:Update()

		if item.VF then
			local var = self:GetVar (item.V)
			self[item.VF](self, item, var)
		end
	end
end

--------
-- Calc

function Nx.Opts:CalcChoices (name, mode, val)

	if name == "FontFace" then

		if mode == "Inc" then
			local i = Nx.Font:GetIndex (val) + 1
			return Nx.Font:GetName (i) or Nx.Font:GetName (1)

		elseif mode == "Get" then

			data = {}

			for n = 1, 999 do
				local name = Nx.Font:GetName (n)
				if not name then
					break
				end

				tinsert (data, name)
			end

			sort (data)

			return data
		end

		return
	elseif name == "Skins" then
		return self.Skins
	elseif name == "HUDAGfx" then

		return Nx.HUD.TexNames

	elseif name == "Anchor" then

		return self.ChoicesAnchor

	elseif name == "Anchor0" then

		return self.ChoicesAnchor0

	elseif name == "Chat" then

		return Nx:prtGetChatFrames()

	elseif name == "Corner" then

		return self.ChoicesCorner

	elseif name == "MapFunc" then

		return Nx.Map:GetFuncs()

	elseif name == "QArea" then

		return self.ChoicesQArea

	end
end

--------
-- Parse var

function Nx.Opts:ParseVar (varName)

	local data = Nx.OptsVars[varName]
	local scope, typ, val, a1 = Nx.Split ("~", data)	
	local opts = scope == "-" and self.COpts or self.Opts

--	Nx.prtVar ("Parse " .. varName, opts[varName])

	local pressed
	local tx

	if typ == "B" then

		pressed = false
		tx = "But"

		if opts[varName] then
			pressed = true
			tx = "ButChk"
		end

		return typ, pressed, tx

	elseif typ == "CH" then

		return typ, a1

	elseif typ == "W" then

		local winName, atName = Nx.Split ("^", val)
		local typ, val = Nx.Window:GetAttribute (winName, atName)

		if typ == "B" then
			if val then
				return typ, true, "ButChk"
			end
			return typ, false, "But"
		end

		return typ, val
	end

	return typ
end

--------
-- Get

function Nx.Opts:GetVar (varName)

	local data = Nx.OptsVars[varName]
	if data then

		local scope, typ, val = Nx.Split ("~", data)
		local opts = scope == "-" and self.COpts or self.Opts

		if typ == "B" then
			return opts[varName]

		elseif typ == "CH" then
			return opts[varName]

		elseif typ == "F" or typ == "I" or typ == "S" then
			return opts[varName]

		end
	end
end

--------
-- Set

function Nx.Opts:SetVar (varName, val)

--	Nx.prtVar ("Set " .. varName, val)

	local data = Nx.OptsVars[varName]
	local scope, typ, vdef, vmin, vmax = Nx.Split ("~", data)
	local opts = scope == "-" and self.COpts or self.Opts

	if typ == "B" then
		opts[varName] = val

	elseif typ == "CH" then
		opts[varName] = val

	elseif typ == "F" or typ == "I" then

		vmin = tonumber (vmin)
		if vmin then
			val = max (val, vmin)
		end

		vmax = tonumber (vmax)
		if vmax then
			val = min (val, vmax)
		end

		opts[varName] = val

	elseif typ == "S" then
		opts[varName] = gsub (val, "~", "?")

	elseif typ == "W" then

		local winName, atName = Nx.Split ("^", vdef)
		Nx.Window:SetAttribute (winName, atName, val)

	else
		return
	end
end

-------------------------------------------------------------------------------
-- EOF

















